# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/google_ads_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import metrics_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_metrics__pb2
from google.ads.google_ads.v2.proto.common import segments_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_segments__pb2
from google.ads.google_ads.v2.proto.resources import account_budget_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__pb2
from google.ads.google_ads.v2.proto.resources import account_budget_proposal_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_ad_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_ad_asset_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__asset__view__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_ad_label_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__label__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_audience_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__audience__view__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_bid_modifier_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__bid__modifier__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_criterion_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_criterion_label_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__label__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_criterion_simulation_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__simulation__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_extension_setting_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__extension__setting__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_feed_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__feed__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_label_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__label__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_simulation_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__simulation__pb2
from google.ads.google_ads.v2.proto.resources import ad_parameter_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__parameter__pb2
from google.ads.google_ads.v2.proto.resources import ad_schedule_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__schedule__view__pb2
from google.ads.google_ads.v2.proto.resources import age_range_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_age__range__view__pb2
from google.ads.google_ads.v2.proto.resources import asset_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_asset__pb2
from google.ads.google_ads.v2.proto.resources import bidding_strategy_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_bidding__strategy__pb2
from google.ads.google_ads.v2.proto.resources import billing_setup_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_billing__setup__pb2
from google.ads.google_ads.v2.proto.resources import campaign_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__pb2
from google.ads.google_ads.v2.proto.resources import campaign_audience_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__audience__view__pb2
from google.ads.google_ads.v2.proto.resources import campaign_bid_modifier_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2
from google.ads.google_ads.v2.proto.resources import campaign_budget_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__budget__pb2
from google.ads.google_ads.v2.proto.resources import campaign_criterion_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__criterion__pb2
from google.ads.google_ads.v2.proto.resources import campaign_criterion_simulation_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__criterion__simulation__pb2
from google.ads.google_ads.v2.proto.resources import campaign_draft_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2
from google.ads.google_ads.v2.proto.resources import campaign_experiment_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__experiment__pb2
from google.ads.google_ads.v2.proto.resources import campaign_extension_setting_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__extension__setting__pb2
from google.ads.google_ads.v2.proto.resources import campaign_feed_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__feed__pb2
from google.ads.google_ads.v2.proto.resources import campaign_label_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__label__pb2
from google.ads.google_ads.v2.proto.resources import campaign_shared_set_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__shared__set__pb2
from google.ads.google_ads.v2.proto.resources import carrier_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_carrier__constant__pb2
from google.ads.google_ads.v2.proto.resources import change_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_change__status__pb2
from google.ads.google_ads.v2.proto.resources import click_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_click__view__pb2
from google.ads.google_ads.v2.proto.resources import conversion_action_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_conversion__action__pb2
from google.ads.google_ads.v2.proto.resources import custom_interest_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_custom__interest__pb2
from google.ads.google_ads.v2.proto.resources import customer_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__pb2
from google.ads.google_ads.v2.proto.resources import customer_client_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__client__pb2
from google.ads.google_ads.v2.proto.resources import customer_client_link_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__client__link__pb2
from google.ads.google_ads.v2.proto.resources import customer_extension_setting_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__extension__setting__pb2
from google.ads.google_ads.v2.proto.resources import customer_feed_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__feed__pb2
from google.ads.google_ads.v2.proto.resources import customer_label_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__label__pb2
from google.ads.google_ads.v2.proto.resources import customer_manager_link_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__manager__link__pb2
from google.ads.google_ads.v2.proto.resources import customer_negative_criterion_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__negative__criterion__pb2
from google.ads.google_ads.v2.proto.resources import detail_placement_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_detail__placement__view__pb2
from google.ads.google_ads.v2.proto.resources import display_keyword_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_display__keyword__view__pb2
from google.ads.google_ads.v2.proto.resources import distance_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_distance__view__pb2
from google.ads.google_ads.v2.proto.resources import domain_category_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_domain__category__pb2
from google.ads.google_ads.v2.proto.resources import dynamic_search_ads_search_term_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_dynamic__search__ads__search__term__view__pb2
from google.ads.google_ads.v2.proto.resources import expanded_landing_page_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_expanded__landing__page__view__pb2
from google.ads.google_ads.v2.proto.resources import extension_feed_item_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_extension__feed__item__pb2
from google.ads.google_ads.v2.proto.resources import feed_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__pb2
from google.ads.google_ads.v2.proto.resources import feed_item_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__pb2
from google.ads.google_ads.v2.proto.resources import feed_item_target_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2
from google.ads.google_ads.v2.proto.resources import feed_mapping_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__mapping__pb2
from google.ads.google_ads.v2.proto.resources import feed_placeholder_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__placeholder__view__pb2
from google.ads.google_ads.v2.proto.resources import gender_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_gender__view__pb2
from google.ads.google_ads.v2.proto.resources import geo_target_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_geo__target__constant__pb2
from google.ads.google_ads.v2.proto.resources import geographic_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_geographic__view__pb2
from google.ads.google_ads.v2.proto.resources import group_placement_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_group__placement__view__pb2
from google.ads.google_ads.v2.proto.resources import hotel_group_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_hotel__group__view__pb2
from google.ads.google_ads.v2.proto.resources import hotel_performance_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_hotel__performance__view__pb2
from google.ads.google_ads.v2.proto.resources import keyword_plan_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__pb2
from google.ads.google_ads.v2.proto.resources import keyword_plan_ad_group_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2
from google.ads.google_ads.v2.proto.resources import keyword_plan_campaign_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2
from google.ads.google_ads.v2.proto.resources import keyword_plan_keyword_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2
from google.ads.google_ads.v2.proto.resources import keyword_plan_negative_keyword_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2
from google.ads.google_ads.v2.proto.resources import keyword_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__view__pb2
from google.ads.google_ads.v2.proto.resources import label_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_label__pb2
from google.ads.google_ads.v2.proto.resources import landing_page_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_landing__page__view__pb2
from google.ads.google_ads.v2.proto.resources import language_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_language__constant__pb2
from google.ads.google_ads.v2.proto.resources import location_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_location__view__pb2
from google.ads.google_ads.v2.proto.resources import managed_placement_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_managed__placement__view__pb2
from google.ads.google_ads.v2.proto.resources import media_file_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_media__file__pb2
from google.ads.google_ads.v2.proto.resources import mobile_app_category_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mobile__app__category__constant__pb2
from google.ads.google_ads.v2.proto.resources import mobile_device_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mobile__device__constant__pb2
from google.ads.google_ads.v2.proto.resources import mutate_job_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mutate__job__pb2
from google.ads.google_ads.v2.proto.resources import operating_system_version_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_operating__system__version__constant__pb2
from google.ads.google_ads.v2.proto.resources import paid_organic_search_term_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_paid__organic__search__term__view__pb2
from google.ads.google_ads.v2.proto.resources import parental_status_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_parental__status__view__pb2
from google.ads.google_ads.v2.proto.resources import product_bidding_category_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_product__bidding__category__constant__pb2
from google.ads.google_ads.v2.proto.resources import product_group_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_product__group__view__pb2
from google.ads.google_ads.v2.proto.resources import recommendation_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_recommendation__pb2
from google.ads.google_ads.v2.proto.resources import remarketing_action_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_remarketing__action__pb2
from google.ads.google_ads.v2.proto.resources import search_term_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_search__term__view__pb2
from google.ads.google_ads.v2.proto.resources import shared_criterion_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__criterion__pb2
from google.ads.google_ads.v2.proto.resources import shared_set_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__set__pb2
from google.ads.google_ads.v2.proto.resources import shopping_performance_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shopping__performance__view__pb2
from google.ads.google_ads.v2.proto.resources import topic_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_topic__constant__pb2
from google.ads.google_ads.v2.proto.resources import topic_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_topic__view__pb2
from google.ads.google_ads.v2.proto.resources import user_interest_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__interest__pb2
from google.ads.google_ads.v2.proto.resources import user_list_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__list__pb2
from google.ads.google_ads.v2.proto.resources import user_location_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__location__view__pb2
from google.ads.google_ads.v2.proto.resources import video_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_video__pb2
from google.ads.google_ads.v2.proto.services import ad_group_ad_label_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2
from google.ads.google_ads.v2.proto.services import ad_group_ad_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2
from google.ads.google_ads.v2.proto.services import ad_group_bid_modifier_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__bid__modifier__service__pb2
from google.ads.google_ads.v2.proto.services import ad_group_criterion_label_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__criterion__label__service__pb2
from google.ads.google_ads.v2.proto.services import ad_group_criterion_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__criterion__service__pb2
from google.ads.google_ads.v2.proto.services import ad_group_extension_setting_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2
from google.ads.google_ads.v2.proto.services import ad_group_feed_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__feed__service__pb2
from google.ads.google_ads.v2.proto.services import ad_group_label_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__label__service__pb2
from google.ads.google_ads.v2.proto.services import ad_group_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2
from google.ads.google_ads.v2.proto.services import ad_parameter_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__parameter__service__pb2
from google.ads.google_ads.v2.proto.services import asset_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_asset__service__pb2
from google.ads.google_ads.v2.proto.services import bidding_strategy_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_bid_modifier_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_budget_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__budget__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_criterion_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_draft_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_experiment_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_extension_setting_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__extension__setting__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_feed_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_label_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__label__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__service__pb2
from google.ads.google_ads.v2.proto.services import campaign_shared_set_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2
from google.ads.google_ads.v2.proto.services import conversion_action_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2
from google.ads.google_ads.v2.proto.services import customer_extension_setting_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2
from google.ads.google_ads.v2.proto.services import customer_feed_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2
from google.ads.google_ads.v2.proto.services import customer_label_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__label__service__pb2
from google.ads.google_ads.v2.proto.services import customer_negative_criterion_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__negative__criterion__service__pb2
from google.ads.google_ads.v2.proto.services import customer_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__service__pb2
from google.ads.google_ads.v2.proto.services import extension_feed_item_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2
from google.ads.google_ads.v2.proto.services import feed_item_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2
from google.ads.google_ads.v2.proto.services import feed_item_target_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2
from google.ads.google_ads.v2.proto.services import feed_mapping_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__mapping__service__pb2
from google.ads.google_ads.v2.proto.services import feed_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__service__pb2
from google.ads.google_ads.v2.proto.services import label_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_label__service__pb2
from google.ads.google_ads.v2.proto.services import media_file_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_media__file__service__pb2
from google.ads.google_ads.v2.proto.services import remarketing_action_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2
from google.ads.google_ads.v2.proto.services import shared_criterion_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_shared__criterion__service__pb2
from google.ads.google_ads.v2.proto.services import shared_set_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_shared__set__service__pb2
from google.ads.google_ads.v2.proto.services import user_list_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/google_ads_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\025GoogleAdsServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\n?google/ads/googleads_v2/proto/services/google_ads_service.proto\x12 google.ads.googleads.v2.services\x1a\x32google/ads/googleads_v2/proto/common/metrics.proto\x1a\x33google/ads/googleads_v2/proto/common/segments.proto\x1a<google/ads/googleads_v2/proto/resources/account_budget.proto\x1a\x45google/ads/googleads_v2/proto/resources/account_budget_proposal.proto\x1a\x36google/ads/googleads_v2/proto/resources/ad_group.proto\x1a\x39google/ads/googleads_v2/proto/resources/ad_group_ad.proto\x1a\x44google/ads/googleads_v2/proto/resources/ad_group_ad_asset_view.proto\x1a?google/ads/googleads_v2/proto/resources/ad_group_ad_label.proto\x1a\x44google/ads/googleads_v2/proto/resources/ad_group_audience_view.proto\x1a\x43google/ads/googleads_v2/proto/resources/ad_group_bid_modifier.proto\x1a@google/ads/googleads_v2/proto/resources/ad_group_criterion.proto\x1a\x46google/ads/googleads_v2/proto/resources/ad_group_criterion_label.proto\x1aKgoogle/ads/googleads_v2/proto/resources/ad_group_criterion_simulation.proto\x1aHgoogle/ads/googleads_v2/proto/resources/ad_group_extension_setting.proto\x1a;google/ads/googleads_v2/proto/resources/ad_group_feed.proto\x1a<google/ads/googleads_v2/proto/resources/ad_group_label.proto\x1a\x41google/ads/googleads_v2/proto/resources/ad_group_simulation.proto\x1a:google/ads/googleads_v2/proto/resources/ad_parameter.proto\x1a>google/ads/googleads_v2/proto/resources/ad_schedule_view.proto\x1a<google/ads/googleads_v2/proto/resources/age_range_view.proto\x1a\x33google/ads/googleads_v2/proto/resources/asset.proto\x1a>google/ads/googleads_v2/proto/resources/bidding_strategy.proto\x1a;google/ads/googleads_v2/proto/resources/billing_setup.proto\x1a\x36google/ads/googleads_v2/proto/resources/campaign.proto\x1a\x44google/ads/googleads_v2/proto/resources/campaign_audience_view.proto\x1a\x43google/ads/googleads_v2/proto/resources/campaign_bid_modifier.proto\x1a=google/ads/googleads_v2/proto/resources/campaign_budget.proto\x1a@google/ads/googleads_v2/proto/resources/campaign_criterion.proto\x1aKgoogle/ads/googleads_v2/proto/resources/campaign_criterion_simulation.proto\x1a<google/ads/googleads_v2/proto/resources/campaign_draft.proto\x1a\x41google/ads/googleads_v2/proto/resources/campaign_experiment.proto\x1aHgoogle/ads/googleads_v2/proto/resources/campaign_extension_setting.proto\x1a;google/ads/googleads_v2/proto/resources/campaign_feed.proto\x1a<google/ads/googleads_v2/proto/resources/campaign_label.proto\x1a\x41google/ads/googleads_v2/proto/resources/campaign_shared_set.proto\x1a>google/ads/googleads_v2/proto/resources/carrier_constant.proto\x1a;google/ads/googleads_v2/proto/resources/change_status.proto\x1a\x38google/ads/googleads_v2/proto/resources/click_view.proto\x1a?google/ads/googleads_v2/proto/resources/conversion_action.proto\x1a=google/ads/googleads_v2/proto/resources/custom_interest.proto\x1a\x36google/ads/googleads_v2/proto/resources/customer.proto\x1a=google/ads/googleads_v2/proto/resources/customer_client.proto\x1a\x42google/ads/googleads_v2/proto/resources/customer_client_link.proto\x1aHgoogle/ads/googleads_v2/proto/resources/customer_extension_setting.proto\x1a;google/ads/googleads_v2/proto/resources/customer_feed.proto\x1a<google/ads/googleads_v2/proto/resources/customer_label.proto\x1a\x43google/ads/googleads_v2/proto/resources/customer_manager_link.proto\x1aIgoogle/ads/googleads_v2/proto/resources/customer_negative_criterion.proto\x1a\x43google/ads/googleads_v2/proto/resources/detail_placement_view.proto\x1a\x42google/ads/googleads_v2/proto/resources/display_keyword_view.proto\x1a;google/ads/googleads_v2/proto/resources/distance_view.proto\x1a=google/ads/googleads_v2/proto/resources/domain_category.proto\x1aQgoogle/ads/googleads_v2/proto/resources/dynamic_search_ads_search_term_view.proto\x1aHgoogle/ads/googleads_v2/proto/resources/expanded_landing_page_view.proto\x1a\x41google/ads/googleads_v2/proto/resources/extension_feed_item.proto\x1a\x32google/ads/googleads_v2/proto/resources/feed.proto\x1a\x37google/ads/googleads_v2/proto/resources/feed_item.proto\x1a>google/ads/googleads_v2/proto/resources/feed_item_target.proto\x1a:google/ads/googleads_v2/proto/resources/feed_mapping.proto\x1a\x43google/ads/googleads_v2/proto/resources/feed_placeholder_view.proto\x1a\x39google/ads/googleads_v2/proto/resources/gender_view.proto\x1a\x41google/ads/googleads_v2/proto/resources/geo_target_constant.proto\x1a=google/ads/googleads_v2/proto/resources/geographic_view.proto\x1a\x42google/ads/googleads_v2/proto/resources/group_placement_view.proto\x1a>google/ads/googleads_v2/proto/resources/hotel_group_view.proto\x1a\x44google/ads/googleads_v2/proto/resources/hotel_performance_view.proto\x1a:google/ads/googleads_v2/proto/resources/keyword_plan.proto\x1a\x43google/ads/googleads_v2/proto/resources/keyword_plan_ad_group.proto\x1a\x43google/ads/googleads_v2/proto/resources/keyword_plan_campaign.proto\x1a\x42google/ads/googleads_v2/proto/resources/keyword_plan_keyword.proto\x1aKgoogle/ads/googleads_v2/proto/resources/keyword_plan_negative_keyword.proto\x1a:google/ads/googleads_v2/proto/resources/keyword_view.proto\x1a\x33google/ads/googleads_v2/proto/resources/label.proto\x1a?google/ads/googleads_v2/proto/resources/landing_page_view.proto\x1a?google/ads/googleads_v2/proto/resources/language_constant.proto\x1a;google/ads/googleads_v2/proto/resources/location_view.proto\x1a\x44google/ads/googleads_v2/proto/resources/managed_placement_view.proto\x1a\x38google/ads/googleads_v2/proto/resources/media_file.proto\x1aJgoogle/ads/googleads_v2/proto/resources/mobile_app_category_constant.proto\x1a\x44google/ads/googleads_v2/proto/resources/mobile_device_constant.proto\x1a\x38google/ads/googleads_v2/proto/resources/mutate_job.proto\x1aOgoogle/ads/googleads_v2/proto/resources/operating_system_version_constant.proto\x1aKgoogle/ads/googleads_v2/proto/resources/paid_organic_search_term_view.proto\x1a\x42google/ads/googleads_v2/proto/resources/parental_status_view.proto\x1aOgoogle/ads/googleads_v2/proto/resources/product_bidding_category_constant.proto\x1a@google/ads/googleads_v2/proto/resources/product_group_view.proto\x1a<google/ads/googleads_v2/proto/resources/recommendation.proto\x1a@google/ads/googleads_v2/proto/resources/remarketing_action.proto\x1a>google/ads/googleads_v2/proto/resources/search_term_view.proto\x1a>google/ads/googleads_v2/proto/resources/shared_criterion.proto\x1a\x38google/ads/googleads_v2/proto/resources/shared_set.proto\x1aGgoogle/ads/googleads_v2/proto/resources/shopping_performance_view.proto\x1a<google/ads/googleads_v2/proto/resources/topic_constant.proto\x1a\x38google/ads/googleads_v2/proto/resources/topic_view.proto\x1a;google/ads/googleads_v2/proto/resources/user_interest.proto\x1a\x37google/ads/googleads_v2/proto/resources/user_list.proto\x1a@google/ads/googleads_v2/proto/resources/user_location_view.proto\x1a\x33google/ads/googleads_v2/proto/resources/video.proto\x1a\x46google/ads/googleads_v2/proto/services/ad_group_ad_label_service.proto\x1a@google/ads/googleads_v2/proto/services/ad_group_ad_service.proto\x1aJgoogle/ads/googleads_v2/proto/services/ad_group_bid_modifier_service.proto\x1aMgoogle/ads/googleads_v2/proto/services/ad_group_criterion_label_service.proto\x1aGgoogle/ads/googleads_v2/proto/services/ad_group_criterion_service.proto\x1aOgoogle/ads/googleads_v2/proto/services/ad_group_extension_setting_service.proto\x1a\x42google/ads/googleads_v2/proto/services/ad_group_feed_service.proto\x1a\x43google/ads/googleads_v2/proto/services/ad_group_label_service.proto\x1a=google/ads/googleads_v2/proto/services/ad_group_service.proto\x1a\x41google/ads/googleads_v2/proto/services/ad_parameter_service.proto\x1a:google/ads/googleads_v2/proto/services/asset_service.proto\x1a\x45google/ads/googleads_v2/proto/services/bidding_strategy_service.proto\x1aJgoogle/ads/googleads_v2/proto/services/campaign_bid_modifier_service.proto\x1a\x44google/ads/googleads_v2/proto/services/campaign_budget_service.proto\x1aGgoogle/ads/googleads_v2/proto/services/campaign_criterion_service.proto\x1a\x43google/ads/googleads_v2/proto/services/campaign_draft_service.proto\x1aHgoogle/ads/googleads_v2/proto/services/campaign_experiment_service.proto\x1aOgoogle/ads/googleads_v2/proto/services/campaign_extension_setting_service.proto\x1a\x42google/ads/googleads_v2/proto/services/campaign_feed_service.proto\x1a\x43google/ads/googleads_v2/proto/services/campaign_label_service.proto\x1a=google/ads/googleads_v2/proto/services/campaign_service.proto\x1aHgoogle/ads/googleads_v2/proto/services/campaign_shared_set_service.proto\x1a\x46google/ads/googleads_v2/proto/services/conversion_action_service.proto\x1aOgoogle/ads/googleads_v2/proto/services/customer_extension_setting_service.proto\x1a\x42google/ads/googleads_v2/proto/services/customer_feed_service.proto\x1a\x43google/ads/googleads_v2/proto/services/customer_label_service.proto\x1aPgoogle/ads/googleads_v2/proto/services/customer_negative_criterion_service.proto\x1a=google/ads/googleads_v2/proto/services/customer_service.proto\x1aHgoogle/ads/googleads_v2/proto/services/extension_feed_item_service.proto\x1a>google/ads/googleads_v2/proto/services/feed_item_service.proto\x1a\x45google/ads/googleads_v2/proto/services/feed_item_target_service.proto\x1a\x41google/ads/googleads_v2/proto/services/feed_mapping_service.proto\x1a\x39google/ads/googleads_v2/proto/services/feed_service.proto\x1a:google/ads/googleads_v2/proto/services/label_service.proto\x1a?google/ads/googleads_v2/proto/services/media_file_service.proto\x1aGgoogle/ads/googleads_v2/proto/services/remarketing_action_service.proto\x1a\x45google/ads/googleads_v2/proto/services/shared_criterion_service.proto\x1a?google/ads/googleads_v2/proto/services/shared_set_service.proto\x1a>google/ads/googleads_v2/proto/services/user_list_service.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/rpc/status.proto\x1a\x17google/api/client.proto\"\x96\x01\n\x16SearchGoogleAdsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x15\n\rvalidate_only\x18\x05 \x01(\x08\x12\x1a\n\x12return_summary_row\x18\x06 \x01(\x08\"\x85\x02\n\x17SearchGoogleAdsResponse\x12?\n\x07results\x18\x01 \x03(\x0b\x32..google.ads.googleads.v2.services.GoogleAdsRow\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x1b\n\x13total_results_count\x18\x03 \x01(\x03\x12.\n\nfield_mask\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x43\n\x0bsummary_row\x18\x06 \x01(\x0b\x32..google.ads.googleads.v2.services.GoogleAdsRow\"\x8b=\n\x0cGoogleAdsRow\x12H\n\x0e\x61\x63\x63ount_budget\x18* \x01(\x0b\x32\x30.google.ads.googleads.v2.resources.AccountBudget\x12Y\n\x17\x61\x63\x63ount_budget_proposal\x18+ \x01(\x0b\x32\x38.google.ads.googleads.v2.resources.AccountBudgetProposal\x12<\n\x08\x61\x64_group\x18\x03 \x01(\x0b\x32*.google.ads.googleads.v2.resources.AdGroup\x12\x41\n\x0b\x61\x64_group_ad\x18\x10 \x01(\x0b\x32,.google.ads.googleads.v2.resources.AdGroupAd\x12V\n\x16\x61\x64_group_ad_asset_view\x18\x83\x01 \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.AdGroupAdAssetView\x12L\n\x11\x61\x64_group_ad_label\x18x \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.AdGroupAdLabel\x12V\n\x16\x61\x64_group_audience_view\x18\x39 \x01(\x0b\x32\x36.google.ads.googleads.v2.resources.AdGroupAudienceView\x12T\n\x15\x61\x64_group_bid_modifier\x18\x18 \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.AdGroupBidModifier\x12O\n\x12\x61\x64_group_criterion\x18\x11 \x01(\x0b\x32\x33.google.ads.googleads.v2.resources.AdGroupCriterion\x12Z\n\x18\x61\x64_group_criterion_label\x18y \x01(\x0b\x32\x38.google.ads.googleads.v2.resources.AdGroupCriterionLabel\x12\x64\n\x1d\x61\x64_group_criterion_simulation\x18n \x01(\x0b\x32=.google.ads.googleads.v2.resources.AdGroupCriterionSimulation\x12^\n\x1a\x61\x64_group_extension_setting\x18p \x01(\x0b\x32:.google.ads.googleads.v2.resources.AdGroupExtensionSetting\x12\x45\n\rad_group_feed\x18\x43 \x01(\x0b\x32..google.ads.googleads.v2.resources.AdGroupFeed\x12G\n\x0e\x61\x64_group_label\x18s \x01(\x0b\x32/.google.ads.googleads.v2.resources.AdGroupLabel\x12Q\n\x13\x61\x64_group_simulation\x18k \x01(\x0b\x32\x34.google.ads.googleads.v2.resources.AdGroupSimulation\x12\x45\n\x0c\x61\x64_parameter\x18\x82\x01 \x01(\x0b\x32..google.ads.googleads.v2.resources.AdParameter\x12G\n\x0e\x61ge_range_view\x18\x30 \x01(\x0b\x32/.google.ads.googleads.v2.resources.AgeRangeView\x12K\n\x10\x61\x64_schedule_view\x18Y \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.AdScheduleView\x12J\n\x0f\x64omain_category\x18[ \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.DomainCategory\x12\x37\n\x05\x61sset\x18i \x01(\x0b\x32(.google.ads.googleads.v2.resources.Asset\x12L\n\x10\x62idding_strategy\x18\x12 \x01(\x0b\x32\x32.google.ads.googleads.v2.resources.BiddingStrategy\x12\x46\n\rbilling_setup\x18) \x01(\x0b\x32/.google.ads.googleads.v2.resources.BillingSetup\x12J\n\x0f\x63\x61mpaign_budget\x18\x13 \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.CampaignBudget\x12=\n\x08\x63\x61mpaign\x18\x02 \x01(\x0b\x32+.google.ads.googleads.v2.resources.Campaign\x12W\n\x16\x63\x61mpaign_audience_view\x18\x45 \x01(\x0b\x32\x37.google.ads.googleads.v2.resources.CampaignAudienceView\x12U\n\x15\x63\x61mpaign_bid_modifier\x18\x1a \x01(\x0b\x32\x36.google.ads.googleads.v2.resources.CampaignBidModifier\x12P\n\x12\x63\x61mpaign_criterion\x18\x14 \x01(\x0b\x32\x34.google.ads.googleads.v2.resources.CampaignCriterion\x12\x65\n\x1d\x63\x61mpaign_criterion_simulation\x18o \x01(\x0b\x32>.google.ads.googleads.v2.resources.CampaignCriterionSimulation\x12H\n\x0e\x63\x61mpaign_draft\x18\x31 \x01(\x0b\x32\x30.google.ads.googleads.v2.resources.CampaignDraft\x12R\n\x13\x63\x61mpaign_experiment\x18T \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.CampaignExperiment\x12_\n\x1a\x63\x61mpaign_extension_setting\x18q \x01(\x0b\x32;.google.ads.googleads.v2.resources.CampaignExtensionSetting\x12\x46\n\rcampaign_feed\x18? \x01(\x0b\x32/.google.ads.googleads.v2.resources.CampaignFeed\x12H\n\x0e\x63\x61mpaign_label\x18l \x01(\x0b\x32\x30.google.ads.googleads.v2.resources.CampaignLabel\x12Q\n\x13\x63\x61mpaign_shared_set\x18\x1e \x01(\x0b\x32\x34.google.ads.googleads.v2.resources.CampaignSharedSet\x12L\n\x10\x63\x61rrier_constant\x18\x42 \x01(\x0b\x32\x32.google.ads.googleads.v2.resources.CarrierConstant\x12\x46\n\rchange_status\x18% \x01(\x0b\x32/.google.ads.googleads.v2.resources.ChangeStatus\x12N\n\x11\x63onversion_action\x18g \x01(\x0b\x32\x33.google.ads.googleads.v2.resources.ConversionAction\x12@\n\nclick_view\x18z \x01(\x0b\x32,.google.ads.googleads.v2.resources.ClickView\x12J\n\x0f\x63ustom_interest\x18h \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.CustomInterest\x12=\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32+.google.ads.googleads.v2.resources.Customer\x12U\n\x15\x63ustomer_manager_link\x18= \x01(\x0b\x32\x36.google.ads.googleads.v2.resources.CustomerManagerLink\x12S\n\x14\x63ustomer_client_link\x18> \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.CustomerClientLink\x12J\n\x0f\x63ustomer_client\x18\x46 \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.CustomerClient\x12_\n\x1a\x63ustomer_extension_setting\x18r \x01(\x0b\x32;.google.ads.googleads.v2.resources.CustomerExtensionSetting\x12\x46\n\rcustomer_feed\x18@ \x01(\x0b\x32/.google.ads.googleads.v2.resources.CustomerFeed\x12H\n\x0e\x63ustomer_label\x18| \x01(\x0b\x32\x30.google.ads.googleads.v2.resources.CustomerLabel\x12\x61\n\x1b\x63ustomer_negative_criterion\x18X \x01(\x0b\x32<.google.ads.googleads.v2.resources.CustomerNegativeCriterion\x12U\n\x15\x64\x65tail_placement_view\x18v \x01(\x0b\x32\x36.google.ads.googleads.v2.resources.DetailPlacementView\x12S\n\x14\x64isplay_keyword_view\x18/ \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.DisplayKeywordView\x12G\n\rdistance_view\x18\x84\x01 \x01(\x0b\x32/.google.ads.googleads.v2.resources.DistanceView\x12n\n#dynamic_search_ads_search_term_view\x18j \x01(\x0b\x32\x41.google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView\x12_\n\x1a\x65xpanded_landing_page_view\x18\x80\x01 \x01(\x0b\x32:.google.ads.googleads.v2.resources.ExpandedLandingPageView\x12Q\n\x13\x65xtension_feed_item\x18U \x01(\x0b\x32\x34.google.ads.googleads.v2.resources.ExtensionFeedItem\x12\x35\n\x04\x66\x65\x65\x64\x18. \x01(\x0b\x32\'.google.ads.googleads.v2.resources.Feed\x12>\n\tfeed_item\x18\x32 \x01(\x0b\x32+.google.ads.googleads.v2.resources.FeedItem\x12K\n\x10\x66\x65\x65\x64_item_target\x18t \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.FeedItemTarget\x12\x44\n\x0c\x66\x65\x65\x64_mapping\x18: \x01(\x0b\x32..google.ads.googleads.v2.resources.FeedMapping\x12U\n\x15\x66\x65\x65\x64_placeholder_view\x18\x61 \x01(\x0b\x32\x36.google.ads.googleads.v2.resources.FeedPlaceholderView\x12\x42\n\x0bgender_view\x18( \x01(\x0b\x32-.google.ads.googleads.v2.resources.GenderView\x12Q\n\x13geo_target_constant\x18\x17 \x01(\x0b\x32\x34.google.ads.googleads.v2.resources.GeoTargetConstant\x12J\n\x0fgeographic_view\x18} \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.GeographicView\x12S\n\x14group_placement_view\x18w \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.GroupPlacementView\x12K\n\x10hotel_group_view\x18\x33 \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.HotelGroupView\x12W\n\x16hotel_performance_view\x18G \x01(\x0b\x32\x37.google.ads.googleads.v2.resources.HotelPerformanceView\x12\x44\n\x0ckeyword_view\x18\x15 \x01(\x0b\x32..google.ads.googleads.v2.resources.KeywordView\x12\x44\n\x0ckeyword_plan\x18  \x01(\x0b\x32..google.ads.googleads.v2.resources.KeywordPlan\x12U\n\x15keyword_plan_campaign\x18! \x01(\x0b\x32\x36.google.ads.googleads.v2.resources.KeywordPlanCampaign\x12\x64\n\x1dkeyword_plan_negative_keyword\x18\" \x01(\x0b\x32=.google.ads.googleads.v2.resources.KeywordPlanNegativeKeyword\x12T\n\x15keyword_plan_ad_group\x18# \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.KeywordPlanAdGroup\x12S\n\x14keyword_plan_keyword\x18$ \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.KeywordPlanKeyword\x12\x37\n\x05label\x18\x34 \x01(\x0b\x32(.google.ads.googleads.v2.resources.Label\x12M\n\x11landing_page_view\x18~ \x01(\x0b\x32\x32.google.ads.googleads.v2.resources.LandingPageView\x12N\n\x11language_constant\x18\x37 \x01(\x0b\x32\x33.google.ads.googleads.v2.resources.LanguageConstant\x12\x46\n\rlocation_view\x18{ \x01(\x0b\x32/.google.ads.googleads.v2.resources.LocationView\x12W\n\x16managed_placement_view\x18\x35 \x01(\x0b\x32\x37.google.ads.googleads.v2.resources.ManagedPlacementView\x12@\n\nmedia_file\x18Z \x01(\x0b\x32,.google.ads.googleads.v2.resources.MediaFile\x12\x62\n\x1cmobile_app_category_constant\x18W \x01(\x0b\x32<.google.ads.googleads.v2.resources.MobileAppCategoryConstant\x12W\n\x16mobile_device_constant\x18\x62 \x01(\x0b\x32\x37.google.ads.googleads.v2.resources.MobileDeviceConstant\x12@\n\nmutate_job\x18\x7f \x01(\x0b\x32,.google.ads.googleads.v2.resources.MutateJob\x12l\n!operating_system_version_constant\x18V \x01(\x0b\x32\x41.google.ads.googleads.v2.resources.OperatingSystemVersionConstant\x12\x64\n\x1dpaid_organic_search_term_view\x18\x81\x01 \x01(\x0b\x32<.google.ads.googleads.v2.resources.PaidOrganicSearchTermView\x12S\n\x14parental_status_view\x18- \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.ParentalStatusView\x12l\n!product_bidding_category_constant\x18m \x01(\x0b\x32\x41.google.ads.googleads.v2.resources.ProductBiddingCategoryConstant\x12O\n\x12product_group_view\x18\x36 \x01(\x0b\x32\x33.google.ads.googleads.v2.resources.ProductGroupView\x12I\n\x0erecommendation\x18\x16 \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.Recommendation\x12K\n\x10search_term_view\x18\x44 \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.SearchTermView\x12L\n\x10shared_criterion\x18\x1d \x01(\x0b\x32\x32.google.ads.googleads.v2.resources.SharedCriterion\x12@\n\nshared_set\x18\x1b \x01(\x0b\x32,.google.ads.googleads.v2.resources.SharedSet\x12]\n\x19shopping_performance_view\x18u \x01(\x0b\x32:.google.ads.googleads.v2.resources.ShoppingPerformanceView\x12@\n\ntopic_view\x18, \x01(\x0b\x32,.google.ads.googleads.v2.resources.TopicView\x12\x46\n\ruser_interest\x18; \x01(\x0b\x32/.google.ads.googleads.v2.resources.UserInterest\x12>\n\tuser_list\x18& \x01(\x0b\x32+.google.ads.googleads.v2.resources.UserList\x12P\n\x12user_location_view\x18\x87\x01 \x01(\x0b\x32\x33.google.ads.googleads.v2.resources.UserLocationView\x12P\n\x12remarketing_action\x18< \x01(\x0b\x32\x34.google.ads.googleads.v2.resources.RemarketingAction\x12H\n\x0etopic_constant\x18\x1f \x01(\x0b\x32\x30.google.ads.googleads.v2.resources.TopicConstant\x12\x37\n\x05video\x18\' \x01(\x0b\x32(.google.ads.googleads.v2.resources.Video\x12\x38\n\x07metrics\x18\x04 \x01(\x0b\x32\'.google.ads.googleads.v2.common.Metrics\x12:\n\x08segments\x18\x66 \x01(\x0b\x32(.google.ads.googleads.v2.common.Segments\"\xab\x01\n\x16MutateGoogleAdsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12L\n\x11mutate_operations\x18\x02 \x03(\x0b\x32\x31.google.ads.googleads.v2.services.MutateOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\xab\x01\n\x17MutateGoogleAdsResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12]\n\x1amutate_operation_responses\x18\x01 \x03(\x0b\x32\x39.google.ads.googleads.v2.services.MutateOperationResponse\"\xb0\x1d\n\x0fMutateOperation\x12`\n\x1b\x61\x64_group_ad_label_operation\x18\x11 \x01(\x0b\x32\x39.google.ads.googleads.v2.services.AdGroupAdLabelOperationH\x00\x12U\n\x15\x61\x64_group_ad_operation\x18\x01 \x01(\x0b\x32\x34.google.ads.googleads.v2.services.AdGroupAdOperationH\x00\x12h\n\x1f\x61\x64_group_bid_modifier_operation\x18\x02 \x01(\x0b\x32=.google.ads.googleads.v2.services.AdGroupBidModifierOperationH\x00\x12n\n\"ad_group_criterion_label_operation\x18\x12 \x01(\x0b\x32@.google.ads.googleads.v2.services.AdGroupCriterionLabelOperationH\x00\x12\x63\n\x1c\x61\x64_group_criterion_operation\x18\x03 \x01(\x0b\x32;.google.ads.googleads.v2.services.AdGroupCriterionOperationH\x00\x12r\n$ad_group_extension_setting_operation\x18\x13 \x01(\x0b\x32\x42.google.ads.googleads.v2.services.AdGroupExtensionSettingOperationH\x00\x12Y\n\x17\x61\x64_group_feed_operation\x18\x14 \x01(\x0b\x32\x36.google.ads.googleads.v2.services.AdGroupFeedOperationH\x00\x12[\n\x18\x61\x64_group_label_operation\x18\x15 \x01(\x0b\x32\x37.google.ads.googleads.v2.services.AdGroupLabelOperationH\x00\x12P\n\x12\x61\x64_group_operation\x18\x05 \x01(\x0b\x32\x32.google.ads.googleads.v2.services.AdGroupOperationH\x00\x12X\n\x16\x61\x64_parameter_operation\x18\x16 \x01(\x0b\x32\x36.google.ads.googleads.v2.services.AdParameterOperationH\x00\x12K\n\x0f\x61sset_operation\x18\x17 \x01(\x0b\x32\x30.google.ads.googleads.v2.services.AssetOperationH\x00\x12`\n\x1a\x62idding_strategy_operation\x18\x06 \x01(\x0b\x32:.google.ads.googleads.v2.services.BiddingStrategyOperationH\x00\x12i\n\x1f\x63\x61mpaign_bid_modifier_operation\x18\x07 \x01(\x0b\x32>.google.ads.googleads.v2.services.CampaignBidModifierOperationH\x00\x12^\n\x19\x63\x61mpaign_budget_operation\x18\x08 \x01(\x0b\x32\x39.google.ads.googleads.v2.services.CampaignBudgetOperationH\x00\x12\x64\n\x1c\x63\x61mpaign_criterion_operation\x18\r \x01(\x0b\x32<.google.ads.googleads.v2.services.CampaignCriterionOperationH\x00\x12\\\n\x18\x63\x61mpaign_draft_operation\x18\x18 \x01(\x0b\x32\x38.google.ads.googleads.v2.services.CampaignDraftOperationH\x00\x12\x66\n\x1d\x63\x61mpaign_experiment_operation\x18\x19 \x01(\x0b\x32=.google.ads.googleads.v2.services.CampaignExperimentOperationH\x00\x12s\n$campaign_extension_setting_operation\x18\x1a \x01(\x0b\x32\x43.google.ads.googleads.v2.services.CampaignExtensionSettingOperationH\x00\x12Z\n\x17\x63\x61mpaign_feed_operation\x18\x1b \x01(\x0b\x32\x37.google.ads.googleads.v2.services.CampaignFeedOperationH\x00\x12\\\n\x18\x63\x61mpaign_label_operation\x18\x1c \x01(\x0b\x32\x38.google.ads.googleads.v2.services.CampaignLabelOperationH\x00\x12Q\n\x12\x63\x61mpaign_operation\x18\n \x01(\x0b\x32\x33.google.ads.googleads.v2.services.CampaignOperationH\x00\x12\x65\n\x1d\x63\x61mpaign_shared_set_operation\x18\x0b \x01(\x0b\x32<.google.ads.googleads.v2.services.CampaignSharedSetOperationH\x00\x12\x62\n\x1b\x63onversion_action_operation\x18\x0c \x01(\x0b\x32;.google.ads.googleads.v2.services.ConversionActionOperationH\x00\x12s\n$customer_extension_setting_operation\x18\x1e \x01(\x0b\x32\x43.google.ads.googleads.v2.services.CustomerExtensionSettingOperationH\x00\x12Z\n\x17\x63ustomer_feed_operation\x18\x1f \x01(\x0b\x32\x37.google.ads.googleads.v2.services.CustomerFeedOperationH\x00\x12\\\n\x18\x63ustomer_label_operation\x18  \x01(\x0b\x32\x38.google.ads.googleads.v2.services.CustomerLabelOperationH\x00\x12u\n%customer_negative_criterion_operation\x18\" \x01(\x0b\x32\x44.google.ads.googleads.v2.services.CustomerNegativeCriterionOperationH\x00\x12Q\n\x12\x63ustomer_operation\x18# \x01(\x0b\x32\x33.google.ads.googleads.v2.services.CustomerOperationH\x00\x12\x65\n\x1d\x65xtension_feed_item_operation\x18$ \x01(\x0b\x32<.google.ads.googleads.v2.services.ExtensionFeedItemOperationH\x00\x12R\n\x13\x66\x65\x65\x64_item_operation\x18% \x01(\x0b\x32\x33.google.ads.googleads.v2.services.FeedItemOperationH\x00\x12_\n\x1a\x66\x65\x65\x64_item_target_operation\x18& \x01(\x0b\x32\x39.google.ads.googleads.v2.services.FeedItemTargetOperationH\x00\x12X\n\x16\x66\x65\x65\x64_mapping_operation\x18\' \x01(\x0b\x32\x36.google.ads.googleads.v2.services.FeedMappingOperationH\x00\x12I\n\x0e\x66\x65\x65\x64_operation\x18( \x01(\x0b\x32/.google.ads.googleads.v2.services.FeedOperationH\x00\x12K\n\x0flabel_operation\x18) \x01(\x0b\x32\x30.google.ads.googleads.v2.services.LabelOperationH\x00\x12T\n\x14media_file_operation\x18* \x01(\x0b\x32\x34.google.ads.googleads.v2.services.MediaFileOperationH\x00\x12\x64\n\x1cremarketing_action_operation\x18+ \x01(\x0b\x32<.google.ads.googleads.v2.services.RemarketingActionOperationH\x00\x12`\n\x1ashared_criterion_operation\x18\x0e \x01(\x0b\x32:.google.ads.googleads.v2.services.SharedCriterionOperationH\x00\x12T\n\x14shared_set_operation\x18\x0f \x01(\x0b\x32\x34.google.ads.googleads.v2.services.SharedSetOperationH\x00\x12R\n\x13user_list_operation\x18\x10 \x01(\x0b\x32\x33.google.ads.googleads.v2.services.UserListOperationH\x00\x42\x0b\n\toperation\"\xb6\x1d\n\x17MutateOperationResponse\x12`\n\x18\x61\x64_group_ad_label_result\x18\x11 \x01(\x0b\x32<.google.ads.googleads.v2.services.MutateAdGroupAdLabelResultH\x00\x12U\n\x12\x61\x64_group_ad_result\x18\x01 \x01(\x0b\x32\x37.google.ads.googleads.v2.services.MutateAdGroupAdResultH\x00\x12h\n\x1c\x61\x64_group_bid_modifier_result\x18\x02 \x01(\x0b\x32@.google.ads.googleads.v2.services.MutateAdGroupBidModifierResultH\x00\x12n\n\x1f\x61\x64_group_criterion_label_result\x18\x12 \x01(\x0b\x32\x43.google.ads.googleads.v2.services.MutateAdGroupCriterionLabelResultH\x00\x12\x63\n\x19\x61\x64_group_criterion_result\x18\x03 \x01(\x0b\x32>.google.ads.googleads.v2.services.MutateAdGroupCriterionResultH\x00\x12r\n!ad_group_extension_setting_result\x18\x13 \x01(\x0b\x32\x45.google.ads.googleads.v2.services.MutateAdGroupExtensionSettingResultH\x00\x12Y\n\x14\x61\x64_group_feed_result\x18\x14 \x01(\x0b\x32\x39.google.ads.googleads.v2.services.MutateAdGroupFeedResultH\x00\x12[\n\x15\x61\x64_group_label_result\x18\x15 \x01(\x0b\x32:.google.ads.googleads.v2.services.MutateAdGroupLabelResultH\x00\x12P\n\x0f\x61\x64_group_result\x18\x05 \x01(\x0b\x32\x35.google.ads.googleads.v2.services.MutateAdGroupResultH\x00\x12X\n\x13\x61\x64_parameter_result\x18\x16 \x01(\x0b\x32\x39.google.ads.googleads.v2.services.MutateAdParameterResultH\x00\x12K\n\x0c\x61sset_result\x18\x17 \x01(\x0b\x32\x33.google.ads.googleads.v2.services.MutateAssetResultH\x00\x12`\n\x17\x62idding_strategy_result\x18\x06 \x01(\x0b\x32=.google.ads.googleads.v2.services.MutateBiddingStrategyResultH\x00\x12i\n\x1c\x63\x61mpaign_bid_modifier_result\x18\x07 \x01(\x0b\x32\x41.google.ads.googleads.v2.services.MutateCampaignBidModifierResultH\x00\x12^\n\x16\x63\x61mpaign_budget_result\x18\x08 \x01(\x0b\x32<.google.ads.googleads.v2.services.MutateCampaignBudgetResultH\x00\x12\x64\n\x19\x63\x61mpaign_criterion_result\x18\r \x01(\x0b\x32?.google.ads.googleads.v2.services.MutateCampaignCriterionResultH\x00\x12\\\n\x15\x63\x61mpaign_draft_result\x18\x18 \x01(\x0b\x32;.google.ads.googleads.v2.services.MutateCampaignDraftResultH\x00\x12\x66\n\x1a\x63\x61mpaign_experiment_result\x18\x19 \x01(\x0b\x32@.google.ads.googleads.v2.services.MutateCampaignExperimentResultH\x00\x12s\n!campaign_extension_setting_result\x18\x1a \x01(\x0b\x32\x46.google.ads.googleads.v2.services.MutateCampaignExtensionSettingResultH\x00\x12Z\n\x14\x63\x61mpaign_feed_result\x18\x1b \x01(\x0b\x32:.google.ads.googleads.v2.services.MutateCampaignFeedResultH\x00\x12\\\n\x15\x63\x61mpaign_label_result\x18\x1c \x01(\x0b\x32;.google.ads.googleads.v2.services.MutateCampaignLabelResultH\x00\x12Q\n\x0f\x63\x61mpaign_result\x18\n \x01(\x0b\x32\x36.google.ads.googleads.v2.services.MutateCampaignResultH\x00\x12\x65\n\x1a\x63\x61mpaign_shared_set_result\x18\x0b \x01(\x0b\x32?.google.ads.googleads.v2.services.MutateCampaignSharedSetResultH\x00\x12\x62\n\x18\x63onversion_action_result\x18\x0c \x01(\x0b\x32>.google.ads.googleads.v2.services.MutateConversionActionResultH\x00\x12s\n!customer_extension_setting_result\x18\x1e \x01(\x0b\x32\x46.google.ads.googleads.v2.services.MutateCustomerExtensionSettingResultH\x00\x12Z\n\x14\x63ustomer_feed_result\x18\x1f \x01(\x0b\x32:.google.ads.googleads.v2.services.MutateCustomerFeedResultH\x00\x12\\\n\x15\x63ustomer_label_result\x18  \x01(\x0b\x32;.google.ads.googleads.v2.services.MutateCustomerLabelResultH\x00\x12t\n\"customer_negative_criterion_result\x18\" \x01(\x0b\x32\x46.google.ads.googleads.v2.services.MutateCustomerNegativeCriteriaResultH\x00\x12Q\n\x0f\x63ustomer_result\x18# \x01(\x0b\x32\x36.google.ads.googleads.v2.services.MutateCustomerResultH\x00\x12\x65\n\x1a\x65xtension_feed_item_result\x18$ \x01(\x0b\x32?.google.ads.googleads.v2.services.MutateExtensionFeedItemResultH\x00\x12R\n\x10\x66\x65\x65\x64_item_result\x18% \x01(\x0b\x32\x36.google.ads.googleads.v2.services.MutateFeedItemResultH\x00\x12_\n\x17\x66\x65\x65\x64_item_target_result\x18& \x01(\x0b\x32<.google.ads.googleads.v2.services.MutateFeedItemTargetResultH\x00\x12X\n\x13\x66\x65\x65\x64_mapping_result\x18\' \x01(\x0b\x32\x39.google.ads.googleads.v2.services.MutateFeedMappingResultH\x00\x12I\n\x0b\x66\x65\x65\x64_result\x18( \x01(\x0b\x32\x32.google.ads.googleads.v2.services.MutateFeedResultH\x00\x12K\n\x0clabel_result\x18) \x01(\x0b\x32\x33.google.ads.googleads.v2.services.MutateLabelResultH\x00\x12T\n\x11media_file_result\x18* \x01(\x0b\x32\x37.google.ads.googleads.v2.services.MutateMediaFileResultH\x00\x12\x64\n\x19remarketing_action_result\x18+ \x01(\x0b\x32?.google.ads.googleads.v2.services.MutateRemarketingActionResultH\x00\x12`\n\x17shared_criterion_result\x18\x0e \x01(\x0b\x32=.google.ads.googleads.v2.services.MutateSharedCriterionResultH\x00\x12T\n\x11shared_set_result\x18\x0f \x01(\x0b\x32\x37.google.ads.googleads.v2.services.MutateSharedSetResultH\x00\x12R\n\x10user_list_result\x18\x10 \x01(\x0b\x32\x36.google.ads.googleads.v2.services.MutateUserListResultH\x00\x42\n\n\x08response2\xa5\x03\n\x10GoogleAdsService\x12\xb8\x01\n\x06Search\x12\x38.google.ads.googleads.v2.services.SearchGoogleAdsRequest\x1a\x39.google.ads.googleads.v2.services.SearchGoogleAdsResponse\"9\x82\xd3\xe4\x93\x02\x33\"./v2/customers/{customer_id=*}/googleAds:search:\x01*\x12\xb8\x01\n\x06Mutate\x12\x38.google.ads.googleads.v2.services.MutateGoogleAdsRequest\x1a\x39.google.ads.googleads.v2.services.MutateGoogleAdsResponse\"9\x82\xd3\xe4\x93\x02\x33\"./v2/customers/{customer_id=*}/googleAds:mutate:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\xfc\x01\n$com.google.ads.googleads.v2.servicesB\x15GoogleAdsServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_metrics__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_segments__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__asset__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__label__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__audience__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__bid__modifier__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__label__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__simulation__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__extension__setting__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__feed__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__label__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__simulation__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__parameter__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__schedule__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_age__range__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_asset__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_bidding__strategy__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_billing__setup__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__audience__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__budget__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__criterion__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__criterion__simulation__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__experiment__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__extension__setting__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__feed__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__label__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__shared__set__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_carrier__constant__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_change__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_click__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_conversion__action__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_custom__interest__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__client__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__client__link__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__extension__setting__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__feed__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__label__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__manager__link__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__negative__criterion__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_detail__placement__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_display__keyword__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_distance__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_domain__category__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_dynamic__search__ads__search__term__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_expanded__landing__page__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_extension__feed__item__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__mapping__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__placeholder__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_gender__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_geo__target__constant__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_geographic__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_group__placement__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_hotel__group__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_hotel__performance__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_label__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_landing__page__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_language__constant__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_location__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_managed__placement__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_media__file__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mobile__app__category__constant__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mobile__device__constant__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mutate__job__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_operating__system__version__constant__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_paid__organic__search__term__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_parental__status__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_product__bidding__category__constant__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_product__group__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_recommendation__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_remarketing__action__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_search__term__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__criterion__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__set__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shopping__performance__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_topic__constant__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_topic__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__interest__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__list__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__location__view__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_video__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__bid__modifier__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__criterion__label__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__criterion__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__feed__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__label__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__parameter__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_asset__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__budget__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__extension__setting__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__label__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__label__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__negative__criterion__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__mapping__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_label__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_media__file__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_shared__criterion__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_shared__set__service__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_SEARCHGOOGLEADSREQUEST = _descriptor.Descriptor(
  name='SearchGoogleAdsRequest',
  full_name='google.ads.googleads.v2.services.SearchGoogleAdsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.SearchGoogleAdsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query', full_name='google.ads.googleads.v2.services.SearchGoogleAdsRequest.query', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.ads.googleads.v2.services.SearchGoogleAdsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.ads.googleads.v2.services.SearchGoogleAdsRequest.page_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.SearchGoogleAdsRequest.validate_only', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='return_summary_row', full_name='google.ads.googleads.v2.services.SearchGoogleAdsRequest.return_summary_row', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9323,
  serialized_end=9473,
)


_SEARCHGOOGLEADSRESPONSE = _descriptor.Descriptor(
  name='SearchGoogleAdsResponse',
  full_name='google.ads.googleads.v2.services.SearchGoogleAdsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.SearchGoogleAdsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.ads.googleads.v2.services.SearchGoogleAdsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_results_count', full_name='google.ads.googleads.v2.services.SearchGoogleAdsResponse.total_results_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_mask', full_name='google.ads.googleads.v2.services.SearchGoogleAdsResponse.field_mask', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_row', full_name='google.ads.googleads.v2.services.SearchGoogleAdsResponse.summary_row', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9476,
  serialized_end=9737,
)


_GOOGLEADSROW = _descriptor.Descriptor(
  name='GoogleAdsRow',
  full_name='google.ads.googleads.v2.services.GoogleAdsRow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_budget', full_name='google.ads.googleads.v2.services.GoogleAdsRow.account_budget', index=0,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_budget_proposal', full_name='google.ads.googleads.v2.services.GoogleAdsRow.account_budget_proposal', index=1,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_ad', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_ad', index=3,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_ad_asset_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_ad_asset_view', index=4,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_ad_label', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_ad_label', index=5,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_audience_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_audience_view', index=6,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_bid_modifier', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_bid_modifier', index=7,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_criterion', index=8,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion_label', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_criterion_label', index=9,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion_simulation', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_criterion_simulation', index=10,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_extension_setting', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_extension_setting', index=11,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_feed', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_feed', index=12,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_label', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_label', index=13,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_simulation', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_group_simulation', index=14,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_parameter', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_parameter', index=15,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='age_range_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.age_range_view', index=16,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_schedule_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.ad_schedule_view', index=17,
      number=89, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain_category', full_name='google.ads.googleads.v2.services.GoogleAdsRow.domain_category', index=18,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset', full_name='google.ads.googleads.v2.services.GoogleAdsRow.asset', index=19,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bidding_strategy', full_name='google.ads.googleads.v2.services.GoogleAdsRow.bidding_strategy', index=20,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billing_setup', full_name='google.ads.googleads.v2.services.GoogleAdsRow.billing_setup', index=21,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_budget', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_budget', index=22,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign', index=23,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_audience_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_audience_view', index=24,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_bid_modifier', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_bid_modifier', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_criterion', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_criterion', index=26,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_criterion_simulation', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_criterion_simulation', index=27,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_draft', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_draft', index=28,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_experiment', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_experiment', index=29,
      number=84, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_extension_setting', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_extension_setting', index=30,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_feed', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_feed', index=31,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_label', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_label', index=32,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_shared_set', full_name='google.ads.googleads.v2.services.GoogleAdsRow.campaign_shared_set', index=33,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='carrier_constant', full_name='google.ads.googleads.v2.services.GoogleAdsRow.carrier_constant', index=34,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_status', full_name='google.ads.googleads.v2.services.GoogleAdsRow.change_status', index=35,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.services.GoogleAdsRow.conversion_action', index=36,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='click_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.click_view', index=37,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_interest', full_name='google.ads.googleads.v2.services.GoogleAdsRow.custom_interest', index=38,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer', full_name='google.ads.googleads.v2.services.GoogleAdsRow.customer', index=39,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_manager_link', full_name='google.ads.googleads.v2.services.GoogleAdsRow.customer_manager_link', index=40,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_client_link', full_name='google.ads.googleads.v2.services.GoogleAdsRow.customer_client_link', index=41,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_client', full_name='google.ads.googleads.v2.services.GoogleAdsRow.customer_client', index=42,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_extension_setting', full_name='google.ads.googleads.v2.services.GoogleAdsRow.customer_extension_setting', index=43,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_feed', full_name='google.ads.googleads.v2.services.GoogleAdsRow.customer_feed', index=44,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_label', full_name='google.ads.googleads.v2.services.GoogleAdsRow.customer_label', index=45,
      number=124, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_negative_criterion', full_name='google.ads.googleads.v2.services.GoogleAdsRow.customer_negative_criterion', index=46,
      number=88, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail_placement_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.detail_placement_view', index=47,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_keyword_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.display_keyword_view', index=48,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distance_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.distance_view', index=49,
      number=132, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamic_search_ads_search_term_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.dynamic_search_ads_search_term_view', index=50,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expanded_landing_page_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.expanded_landing_page_view', index=51,
      number=128, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension_feed_item', full_name='google.ads.googleads.v2.services.GoogleAdsRow.extension_feed_item', index=52,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed', full_name='google.ads.googleads.v2.services.GoogleAdsRow.feed', index=53,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item', full_name='google.ads.googleads.v2.services.GoogleAdsRow.feed_item', index=54,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_target', full_name='google.ads.googleads.v2.services.GoogleAdsRow.feed_item_target', index=55,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_mapping', full_name='google.ads.googleads.v2.services.GoogleAdsRow.feed_mapping', index=56,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_placeholder_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.feed_placeholder_view', index=57,
      number=97, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gender_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.gender_view', index=58,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_constant', full_name='google.ads.googleads.v2.services.GoogleAdsRow.geo_target_constant', index=59,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geographic_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.geographic_view', index=60,
      number=125, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_placement_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.group_placement_view', index=61,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_group_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.hotel_group_view', index=62,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_performance_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.hotel_performance_view', index=63,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.keyword_view', index=64,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan', full_name='google.ads.googleads.v2.services.GoogleAdsRow.keyword_plan', index=65,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_campaign', full_name='google.ads.googleads.v2.services.GoogleAdsRow.keyword_plan_campaign', index=66,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_negative_keyword', full_name='google.ads.googleads.v2.services.GoogleAdsRow.keyword_plan_negative_keyword', index=67,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_ad_group', full_name='google.ads.googleads.v2.services.GoogleAdsRow.keyword_plan_ad_group', index=68,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_keyword', full_name='google.ads.googleads.v2.services.GoogleAdsRow.keyword_plan_keyword', index=69,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='google.ads.googleads.v2.services.GoogleAdsRow.label', index=70,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='landing_page_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.landing_page_view', index=71,
      number=126, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_constant', full_name='google.ads.googleads.v2.services.GoogleAdsRow.language_constant', index=72,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.location_view', index=73,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='managed_placement_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.managed_placement_view', index=74,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_file', full_name='google.ads.googleads.v2.services.GoogleAdsRow.media_file', index=75,
      number=90, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_app_category_constant', full_name='google.ads.googleads.v2.services.GoogleAdsRow.mobile_app_category_constant', index=76,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_device_constant', full_name='google.ads.googleads.v2.services.GoogleAdsRow.mobile_device_constant', index=77,
      number=98, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mutate_job', full_name='google.ads.googleads.v2.services.GoogleAdsRow.mutate_job', index=78,
      number=127, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operating_system_version_constant', full_name='google.ads.googleads.v2.services.GoogleAdsRow.operating_system_version_constant', index=79,
      number=86, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paid_organic_search_term_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.paid_organic_search_term_view', index=80,
      number=129, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parental_status_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.parental_status_view', index=81,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_constant', full_name='google.ads.googleads.v2.services.GoogleAdsRow.product_bidding_category_constant', index=82,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_group_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.product_group_view', index=83,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommendation', full_name='google.ads.googleads.v2.services.GoogleAdsRow.recommendation', index=84,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_term_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.search_term_view', index=85,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_criterion', full_name='google.ads.googleads.v2.services.GoogleAdsRow.shared_criterion', index=86,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_set', full_name='google.ads.googleads.v2.services.GoogleAdsRow.shared_set', index=87,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shopping_performance_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.shopping_performance_view', index=88,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.topic_view', index=89,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_interest', full_name='google.ads.googleads.v2.services.GoogleAdsRow.user_interest', index=90,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_list', full_name='google.ads.googleads.v2.services.GoogleAdsRow.user_list', index=91,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_location_view', full_name='google.ads.googleads.v2.services.GoogleAdsRow.user_location_view', index=92,
      number=135, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remarketing_action', full_name='google.ads.googleads.v2.services.GoogleAdsRow.remarketing_action', index=93,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic_constant', full_name='google.ads.googleads.v2.services.GoogleAdsRow.topic_constant', index=94,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video', full_name='google.ads.googleads.v2.services.GoogleAdsRow.video', index=95,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='google.ads.googleads.v2.services.GoogleAdsRow.metrics', index=96,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segments', full_name='google.ads.googleads.v2.services.GoogleAdsRow.segments', index=97,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9740,
  serialized_end=17559,
)


_MUTATEGOOGLEADSREQUEST = _descriptor.Descriptor(
  name='MutateGoogleAdsRequest',
  full_name='google.ads.googleads.v2.services.MutateGoogleAdsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateGoogleAdsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mutate_operations', full_name='google.ads.googleads.v2.services.MutateGoogleAdsRequest.mutate_operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v2.services.MutateGoogleAdsRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.MutateGoogleAdsRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17562,
  serialized_end=17733,
)


_MUTATEGOOGLEADSRESPONSE = _descriptor.Descriptor(
  name='MutateGoogleAdsResponse',
  full_name='google.ads.googleads.v2.services.MutateGoogleAdsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v2.services.MutateGoogleAdsResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mutate_operation_responses', full_name='google.ads.googleads.v2.services.MutateGoogleAdsResponse.mutate_operation_responses', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17736,
  serialized_end=17907,
)


_MUTATEOPERATION = _descriptor.Descriptor(
  name='MutateOperation',
  full_name='google.ads.googleads.v2.services.MutateOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_group_ad_label_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_group_ad_label_operation', index=0,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_ad_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_group_ad_operation', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_bid_modifier_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_group_bid_modifier_operation', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion_label_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_group_criterion_label_operation', index=3,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_group_criterion_operation', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_extension_setting_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_group_extension_setting_operation', index=5,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_feed_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_group_feed_operation', index=6,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_label_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_group_label_operation', index=7,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_group_operation', index=8,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_parameter_operation', full_name='google.ads.googleads.v2.services.MutateOperation.ad_parameter_operation', index=9,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset_operation', full_name='google.ads.googleads.v2.services.MutateOperation.asset_operation', index=10,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bidding_strategy_operation', full_name='google.ads.googleads.v2.services.MutateOperation.bidding_strategy_operation', index=11,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_bid_modifier_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_bid_modifier_operation', index=12,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_budget_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_budget_operation', index=13,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_criterion_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_criterion_operation', index=14,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_draft_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_draft_operation', index=15,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_experiment_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_experiment_operation', index=16,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_extension_setting_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_extension_setting_operation', index=17,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_feed_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_feed_operation', index=18,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_label_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_label_operation', index=19,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_operation', index=20,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_shared_set_operation', full_name='google.ads.googleads.v2.services.MutateOperation.campaign_shared_set_operation', index=21,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action_operation', full_name='google.ads.googleads.v2.services.MutateOperation.conversion_action_operation', index=22,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_extension_setting_operation', full_name='google.ads.googleads.v2.services.MutateOperation.customer_extension_setting_operation', index=23,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_feed_operation', full_name='google.ads.googleads.v2.services.MutateOperation.customer_feed_operation', index=24,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_label_operation', full_name='google.ads.googleads.v2.services.MutateOperation.customer_label_operation', index=25,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_negative_criterion_operation', full_name='google.ads.googleads.v2.services.MutateOperation.customer_negative_criterion_operation', index=26,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_operation', full_name='google.ads.googleads.v2.services.MutateOperation.customer_operation', index=27,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension_feed_item_operation', full_name='google.ads.googleads.v2.services.MutateOperation.extension_feed_item_operation', index=28,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_operation', full_name='google.ads.googleads.v2.services.MutateOperation.feed_item_operation', index=29,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_target_operation', full_name='google.ads.googleads.v2.services.MutateOperation.feed_item_target_operation', index=30,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_mapping_operation', full_name='google.ads.googleads.v2.services.MutateOperation.feed_mapping_operation', index=31,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_operation', full_name='google.ads.googleads.v2.services.MutateOperation.feed_operation', index=32,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_operation', full_name='google.ads.googleads.v2.services.MutateOperation.label_operation', index=33,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_file_operation', full_name='google.ads.googleads.v2.services.MutateOperation.media_file_operation', index=34,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remarketing_action_operation', full_name='google.ads.googleads.v2.services.MutateOperation.remarketing_action_operation', index=35,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_criterion_operation', full_name='google.ads.googleads.v2.services.MutateOperation.shared_criterion_operation', index=36,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_set_operation', full_name='google.ads.googleads.v2.services.MutateOperation.shared_set_operation', index=37,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_list_operation', full_name='google.ads.googleads.v2.services.MutateOperation.user_list_operation', index=38,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.MutateOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=17910,
  serialized_end=21670,
)


_MUTATEOPERATIONRESPONSE = _descriptor.Descriptor(
  name='MutateOperationResponse',
  full_name='google.ads.googleads.v2.services.MutateOperationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_group_ad_label_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_group_ad_label_result', index=0,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_ad_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_group_ad_result', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_bid_modifier_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_group_bid_modifier_result', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion_label_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_group_criterion_label_result', index=3,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_group_criterion_result', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_extension_setting_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_group_extension_setting_result', index=5,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_feed_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_group_feed_result', index=6,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_label_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_group_label_result', index=7,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_group_result', index=8,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_parameter_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.ad_parameter_result', index=9,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.asset_result', index=10,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bidding_strategy_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.bidding_strategy_result', index=11,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_bid_modifier_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_bid_modifier_result', index=12,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_budget_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_budget_result', index=13,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_criterion_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_criterion_result', index=14,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_draft_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_draft_result', index=15,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_experiment_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_experiment_result', index=16,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_extension_setting_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_extension_setting_result', index=17,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_feed_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_feed_result', index=18,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_label_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_label_result', index=19,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_result', index=20,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_shared_set_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.campaign_shared_set_result', index=21,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.conversion_action_result', index=22,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_extension_setting_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.customer_extension_setting_result', index=23,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_feed_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.customer_feed_result', index=24,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_label_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.customer_label_result', index=25,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_negative_criterion_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.customer_negative_criterion_result', index=26,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.customer_result', index=27,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension_feed_item_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.extension_feed_item_result', index=28,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.feed_item_result', index=29,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_target_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.feed_item_target_result', index=30,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_mapping_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.feed_mapping_result', index=31,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.feed_result', index=32,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.label_result', index=33,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_file_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.media_file_result', index=34,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remarketing_action_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.remarketing_action_result', index=35,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_criterion_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.shared_criterion_result', index=36,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_set_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.shared_set_result', index=37,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_list_result', full_name='google.ads.googleads.v2.services.MutateOperationResponse.user_list_result', index=38,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='google.ads.googleads.v2.services.MutateOperationResponse.response',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=21673,
  serialized_end=25439,
)

_SEARCHGOOGLEADSRESPONSE.fields_by_name['results'].message_type = _GOOGLEADSROW
_SEARCHGOOGLEADSRESPONSE.fields_by_name['field_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_SEARCHGOOGLEADSRESPONSE.fields_by_name['summary_row'].message_type = _GOOGLEADSROW
_GOOGLEADSROW.fields_by_name['account_budget'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__pb2._ACCOUNTBUDGET
_GOOGLEADSROW.fields_by_name['account_budget_proposal'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2._ACCOUNTBUDGETPROPOSAL
_GOOGLEADSROW.fields_by_name['ad_group'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__pb2._ADGROUP
_GOOGLEADSROW.fields_by_name['ad_group_ad'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__pb2._ADGROUPAD
_GOOGLEADSROW.fields_by_name['ad_group_ad_asset_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__asset__view__pb2._ADGROUPADASSETVIEW
_GOOGLEADSROW.fields_by_name['ad_group_ad_label'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__label__pb2._ADGROUPADLABEL
_GOOGLEADSROW.fields_by_name['ad_group_audience_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__audience__view__pb2._ADGROUPAUDIENCEVIEW
_GOOGLEADSROW.fields_by_name['ad_group_bid_modifier'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__bid__modifier__pb2._ADGROUPBIDMODIFIER
_GOOGLEADSROW.fields_by_name['ad_group_criterion'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__pb2._ADGROUPCRITERION
_GOOGLEADSROW.fields_by_name['ad_group_criterion_label'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__label__pb2._ADGROUPCRITERIONLABEL
_GOOGLEADSROW.fields_by_name['ad_group_criterion_simulation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__simulation__pb2._ADGROUPCRITERIONSIMULATION
_GOOGLEADSROW.fields_by_name['ad_group_extension_setting'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__extension__setting__pb2._ADGROUPEXTENSIONSETTING
_GOOGLEADSROW.fields_by_name['ad_group_feed'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__feed__pb2._ADGROUPFEED
_GOOGLEADSROW.fields_by_name['ad_group_label'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__label__pb2._ADGROUPLABEL
_GOOGLEADSROW.fields_by_name['ad_group_simulation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__simulation__pb2._ADGROUPSIMULATION
_GOOGLEADSROW.fields_by_name['ad_parameter'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__parameter__pb2._ADPARAMETER
_GOOGLEADSROW.fields_by_name['age_range_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_age__range__view__pb2._AGERANGEVIEW
_GOOGLEADSROW.fields_by_name['ad_schedule_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__schedule__view__pb2._ADSCHEDULEVIEW
_GOOGLEADSROW.fields_by_name['domain_category'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_domain__category__pb2._DOMAINCATEGORY
_GOOGLEADSROW.fields_by_name['asset'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_asset__pb2._ASSET
_GOOGLEADSROW.fields_by_name['bidding_strategy'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_bidding__strategy__pb2._BIDDINGSTRATEGY
_GOOGLEADSROW.fields_by_name['billing_setup'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_billing__setup__pb2._BILLINGSETUP
_GOOGLEADSROW.fields_by_name['campaign_budget'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__budget__pb2._CAMPAIGNBUDGET
_GOOGLEADSROW.fields_by_name['campaign'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__pb2._CAMPAIGN
_GOOGLEADSROW.fields_by_name['campaign_audience_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__audience__view__pb2._CAMPAIGNAUDIENCEVIEW
_GOOGLEADSROW.fields_by_name['campaign_bid_modifier'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__bid__modifier__pb2._CAMPAIGNBIDMODIFIER
_GOOGLEADSROW.fields_by_name['campaign_criterion'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__criterion__pb2._CAMPAIGNCRITERION
_GOOGLEADSROW.fields_by_name['campaign_criterion_simulation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__criterion__simulation__pb2._CAMPAIGNCRITERIONSIMULATION
_GOOGLEADSROW.fields_by_name['campaign_draft'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2._CAMPAIGNDRAFT
_GOOGLEADSROW.fields_by_name['campaign_experiment'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__experiment__pb2._CAMPAIGNEXPERIMENT
_GOOGLEADSROW.fields_by_name['campaign_extension_setting'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__extension__setting__pb2._CAMPAIGNEXTENSIONSETTING
_GOOGLEADSROW.fields_by_name['campaign_feed'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__feed__pb2._CAMPAIGNFEED
_GOOGLEADSROW.fields_by_name['campaign_label'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__label__pb2._CAMPAIGNLABEL
_GOOGLEADSROW.fields_by_name['campaign_shared_set'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__shared__set__pb2._CAMPAIGNSHAREDSET
_GOOGLEADSROW.fields_by_name['carrier_constant'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_carrier__constant__pb2._CARRIERCONSTANT
_GOOGLEADSROW.fields_by_name['change_status'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_change__status__pb2._CHANGESTATUS
_GOOGLEADSROW.fields_by_name['conversion_action'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_conversion__action__pb2._CONVERSIONACTION
_GOOGLEADSROW.fields_by_name['click_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_click__view__pb2._CLICKVIEW
_GOOGLEADSROW.fields_by_name['custom_interest'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_custom__interest__pb2._CUSTOMINTEREST
_GOOGLEADSROW.fields_by_name['customer'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__pb2._CUSTOMER
_GOOGLEADSROW.fields_by_name['customer_manager_link'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__manager__link__pb2._CUSTOMERMANAGERLINK
_GOOGLEADSROW.fields_by_name['customer_client_link'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__client__link__pb2._CUSTOMERCLIENTLINK
_GOOGLEADSROW.fields_by_name['customer_client'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__client__pb2._CUSTOMERCLIENT
_GOOGLEADSROW.fields_by_name['customer_extension_setting'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__extension__setting__pb2._CUSTOMEREXTENSIONSETTING
_GOOGLEADSROW.fields_by_name['customer_feed'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__feed__pb2._CUSTOMERFEED
_GOOGLEADSROW.fields_by_name['customer_label'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__label__pb2._CUSTOMERLABEL
_GOOGLEADSROW.fields_by_name['customer_negative_criterion'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__negative__criterion__pb2._CUSTOMERNEGATIVECRITERION
_GOOGLEADSROW.fields_by_name['detail_placement_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_detail__placement__view__pb2._DETAILPLACEMENTVIEW
_GOOGLEADSROW.fields_by_name['display_keyword_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_display__keyword__view__pb2._DISPLAYKEYWORDVIEW
_GOOGLEADSROW.fields_by_name['distance_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_distance__view__pb2._DISTANCEVIEW
_GOOGLEADSROW.fields_by_name['dynamic_search_ads_search_term_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_dynamic__search__ads__search__term__view__pb2._DYNAMICSEARCHADSSEARCHTERMVIEW
_GOOGLEADSROW.fields_by_name['expanded_landing_page_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_expanded__landing__page__view__pb2._EXPANDEDLANDINGPAGEVIEW
_GOOGLEADSROW.fields_by_name['extension_feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_extension__feed__item__pb2._EXTENSIONFEEDITEM
_GOOGLEADSROW.fields_by_name['feed'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__pb2._FEED
_GOOGLEADSROW.fields_by_name['feed_item'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__pb2._FEEDITEM
_GOOGLEADSROW.fields_by_name['feed_item_target'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2._FEEDITEMTARGET
_GOOGLEADSROW.fields_by_name['feed_mapping'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__mapping__pb2._FEEDMAPPING
_GOOGLEADSROW.fields_by_name['feed_placeholder_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__placeholder__view__pb2._FEEDPLACEHOLDERVIEW
_GOOGLEADSROW.fields_by_name['gender_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_gender__view__pb2._GENDERVIEW
_GOOGLEADSROW.fields_by_name['geo_target_constant'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_geo__target__constant__pb2._GEOTARGETCONSTANT
_GOOGLEADSROW.fields_by_name['geographic_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_geographic__view__pb2._GEOGRAPHICVIEW
_GOOGLEADSROW.fields_by_name['group_placement_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_group__placement__view__pb2._GROUPPLACEMENTVIEW
_GOOGLEADSROW.fields_by_name['hotel_group_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_hotel__group__view__pb2._HOTELGROUPVIEW
_GOOGLEADSROW.fields_by_name['hotel_performance_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_hotel__performance__view__pb2._HOTELPERFORMANCEVIEW
_GOOGLEADSROW.fields_by_name['keyword_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__view__pb2._KEYWORDVIEW
_GOOGLEADSROW.fields_by_name['keyword_plan'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__pb2._KEYWORDPLAN
_GOOGLEADSROW.fields_by_name['keyword_plan_campaign'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2._KEYWORDPLANCAMPAIGN
_GOOGLEADSROW.fields_by_name['keyword_plan_negative_keyword'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2._KEYWORDPLANNEGATIVEKEYWORD
_GOOGLEADSROW.fields_by_name['keyword_plan_ad_group'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2._KEYWORDPLANADGROUP
_GOOGLEADSROW.fields_by_name['keyword_plan_keyword'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__keyword__pb2._KEYWORDPLANKEYWORD
_GOOGLEADSROW.fields_by_name['label'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_label__pb2._LABEL
_GOOGLEADSROW.fields_by_name['landing_page_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_landing__page__view__pb2._LANDINGPAGEVIEW
_GOOGLEADSROW.fields_by_name['language_constant'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_language__constant__pb2._LANGUAGECONSTANT
_GOOGLEADSROW.fields_by_name['location_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_location__view__pb2._LOCATIONVIEW
_GOOGLEADSROW.fields_by_name['managed_placement_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_managed__placement__view__pb2._MANAGEDPLACEMENTVIEW
_GOOGLEADSROW.fields_by_name['media_file'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_media__file__pb2._MEDIAFILE
_GOOGLEADSROW.fields_by_name['mobile_app_category_constant'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mobile__app__category__constant__pb2._MOBILEAPPCATEGORYCONSTANT
_GOOGLEADSROW.fields_by_name['mobile_device_constant'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mobile__device__constant__pb2._MOBILEDEVICECONSTANT
_GOOGLEADSROW.fields_by_name['mutate_job'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mutate__job__pb2._MUTATEJOB
_GOOGLEADSROW.fields_by_name['operating_system_version_constant'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_operating__system__version__constant__pb2._OPERATINGSYSTEMVERSIONCONSTANT
_GOOGLEADSROW.fields_by_name['paid_organic_search_term_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_paid__organic__search__term__view__pb2._PAIDORGANICSEARCHTERMVIEW
_GOOGLEADSROW.fields_by_name['parental_status_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_parental__status__view__pb2._PARENTALSTATUSVIEW
_GOOGLEADSROW.fields_by_name['product_bidding_category_constant'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_product__bidding__category__constant__pb2._PRODUCTBIDDINGCATEGORYCONSTANT
_GOOGLEADSROW.fields_by_name['product_group_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_product__group__view__pb2._PRODUCTGROUPVIEW
_GOOGLEADSROW.fields_by_name['recommendation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_recommendation__pb2._RECOMMENDATION
_GOOGLEADSROW.fields_by_name['search_term_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_search__term__view__pb2._SEARCHTERMVIEW
_GOOGLEADSROW.fields_by_name['shared_criterion'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__criterion__pb2._SHAREDCRITERION
_GOOGLEADSROW.fields_by_name['shared_set'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__set__pb2._SHAREDSET
_GOOGLEADSROW.fields_by_name['shopping_performance_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shopping__performance__view__pb2._SHOPPINGPERFORMANCEVIEW
_GOOGLEADSROW.fields_by_name['topic_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_topic__view__pb2._TOPICVIEW
_GOOGLEADSROW.fields_by_name['user_interest'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__interest__pb2._USERINTEREST
_GOOGLEADSROW.fields_by_name['user_list'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__list__pb2._USERLIST
_GOOGLEADSROW.fields_by_name['user_location_view'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__location__view__pb2._USERLOCATIONVIEW
_GOOGLEADSROW.fields_by_name['remarketing_action'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_remarketing__action__pb2._REMARKETINGACTION
_GOOGLEADSROW.fields_by_name['topic_constant'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_topic__constant__pb2._TOPICCONSTANT
_GOOGLEADSROW.fields_by_name['video'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_video__pb2._VIDEO
_GOOGLEADSROW.fields_by_name['metrics'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_metrics__pb2._METRICS
_GOOGLEADSROW.fields_by_name['segments'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_segments__pb2._SEGMENTS
_MUTATEGOOGLEADSREQUEST.fields_by_name['mutate_operations'].message_type = _MUTATEOPERATION
_MUTATEGOOGLEADSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATEGOOGLEADSRESPONSE.fields_by_name['mutate_operation_responses'].message_type = _MUTATEOPERATIONRESPONSE
_MUTATEOPERATION.fields_by_name['ad_group_ad_label_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2._ADGROUPADLABELOPERATION
_MUTATEOPERATION.fields_by_name['ad_group_ad_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2._ADGROUPADOPERATION
_MUTATEOPERATION.fields_by_name['ad_group_bid_modifier_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__bid__modifier__service__pb2._ADGROUPBIDMODIFIEROPERATION
_MUTATEOPERATION.fields_by_name['ad_group_criterion_label_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__criterion__label__service__pb2._ADGROUPCRITERIONLABELOPERATION
_MUTATEOPERATION.fields_by_name['ad_group_criterion_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__criterion__service__pb2._ADGROUPCRITERIONOPERATION
_MUTATEOPERATION.fields_by_name['ad_group_extension_setting_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2._ADGROUPEXTENSIONSETTINGOPERATION
_MUTATEOPERATION.fields_by_name['ad_group_feed_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__feed__service__pb2._ADGROUPFEEDOPERATION
_MUTATEOPERATION.fields_by_name['ad_group_label_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__label__service__pb2._ADGROUPLABELOPERATION
_MUTATEOPERATION.fields_by_name['ad_group_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2._ADGROUPOPERATION
_MUTATEOPERATION.fields_by_name['ad_parameter_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__parameter__service__pb2._ADPARAMETEROPERATION
_MUTATEOPERATION.fields_by_name['asset_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_asset__service__pb2._ASSETOPERATION
_MUTATEOPERATION.fields_by_name['bidding_strategy_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2._BIDDINGSTRATEGYOPERATION
_MUTATEOPERATION.fields_by_name['campaign_bid_modifier_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2._CAMPAIGNBIDMODIFIEROPERATION
_MUTATEOPERATION.fields_by_name['campaign_budget_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__budget__service__pb2._CAMPAIGNBUDGETOPERATION
_MUTATEOPERATION.fields_by_name['campaign_criterion_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2._CAMPAIGNCRITERIONOPERATION
_MUTATEOPERATION.fields_by_name['campaign_draft_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2._CAMPAIGNDRAFTOPERATION
_MUTATEOPERATION.fields_by_name['campaign_experiment_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2._CAMPAIGNEXPERIMENTOPERATION
_MUTATEOPERATION.fields_by_name['campaign_extension_setting_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__extension__setting__service__pb2._CAMPAIGNEXTENSIONSETTINGOPERATION
_MUTATEOPERATION.fields_by_name['campaign_feed_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2._CAMPAIGNFEEDOPERATION
_MUTATEOPERATION.fields_by_name['campaign_label_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__label__service__pb2._CAMPAIGNLABELOPERATION
_MUTATEOPERATION.fields_by_name['campaign_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__service__pb2._CAMPAIGNOPERATION
_MUTATEOPERATION.fields_by_name['campaign_shared_set_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2._CAMPAIGNSHAREDSETOPERATION
_MUTATEOPERATION.fields_by_name['conversion_action_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2._CONVERSIONACTIONOPERATION
_MUTATEOPERATION.fields_by_name['customer_extension_setting_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2._CUSTOMEREXTENSIONSETTINGOPERATION
_MUTATEOPERATION.fields_by_name['customer_feed_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2._CUSTOMERFEEDOPERATION
_MUTATEOPERATION.fields_by_name['customer_label_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__label__service__pb2._CUSTOMERLABELOPERATION
_MUTATEOPERATION.fields_by_name['customer_negative_criterion_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__negative__criterion__service__pb2._CUSTOMERNEGATIVECRITERIONOPERATION
_MUTATEOPERATION.fields_by_name['customer_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__service__pb2._CUSTOMEROPERATION
_MUTATEOPERATION.fields_by_name['extension_feed_item_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2._EXTENSIONFEEDITEMOPERATION
_MUTATEOPERATION.fields_by_name['feed_item_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2._FEEDITEMOPERATION
_MUTATEOPERATION.fields_by_name['feed_item_target_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2._FEEDITEMTARGETOPERATION
_MUTATEOPERATION.fields_by_name['feed_mapping_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__mapping__service__pb2._FEEDMAPPINGOPERATION
_MUTATEOPERATION.fields_by_name['feed_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__service__pb2._FEEDOPERATION
_MUTATEOPERATION.fields_by_name['label_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_label__service__pb2._LABELOPERATION
_MUTATEOPERATION.fields_by_name['media_file_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_media__file__service__pb2._MEDIAFILEOPERATION
_MUTATEOPERATION.fields_by_name['remarketing_action_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2._REMARKETINGACTIONOPERATION
_MUTATEOPERATION.fields_by_name['shared_criterion_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_shared__criterion__service__pb2._SHAREDCRITERIONOPERATION
_MUTATEOPERATION.fields_by_name['shared_set_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_shared__set__service__pb2._SHAREDSETOPERATION
_MUTATEOPERATION.fields_by_name['user_list_operation'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2._USERLISTOPERATION
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_group_ad_label_operation'])
_MUTATEOPERATION.fields_by_name['ad_group_ad_label_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_group_ad_operation'])
_MUTATEOPERATION.fields_by_name['ad_group_ad_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_group_bid_modifier_operation'])
_MUTATEOPERATION.fields_by_name['ad_group_bid_modifier_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_group_criterion_label_operation'])
_MUTATEOPERATION.fields_by_name['ad_group_criterion_label_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_group_criterion_operation'])
_MUTATEOPERATION.fields_by_name['ad_group_criterion_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_group_extension_setting_operation'])
_MUTATEOPERATION.fields_by_name['ad_group_extension_setting_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_group_feed_operation'])
_MUTATEOPERATION.fields_by_name['ad_group_feed_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_group_label_operation'])
_MUTATEOPERATION.fields_by_name['ad_group_label_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_group_operation'])
_MUTATEOPERATION.fields_by_name['ad_group_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['ad_parameter_operation'])
_MUTATEOPERATION.fields_by_name['ad_parameter_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['asset_operation'])
_MUTATEOPERATION.fields_by_name['asset_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['bidding_strategy_operation'])
_MUTATEOPERATION.fields_by_name['bidding_strategy_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_bid_modifier_operation'])
_MUTATEOPERATION.fields_by_name['campaign_bid_modifier_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_budget_operation'])
_MUTATEOPERATION.fields_by_name['campaign_budget_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_criterion_operation'])
_MUTATEOPERATION.fields_by_name['campaign_criterion_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_draft_operation'])
_MUTATEOPERATION.fields_by_name['campaign_draft_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_experiment_operation'])
_MUTATEOPERATION.fields_by_name['campaign_experiment_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_extension_setting_operation'])
_MUTATEOPERATION.fields_by_name['campaign_extension_setting_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_feed_operation'])
_MUTATEOPERATION.fields_by_name['campaign_feed_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_label_operation'])
_MUTATEOPERATION.fields_by_name['campaign_label_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_operation'])
_MUTATEOPERATION.fields_by_name['campaign_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['campaign_shared_set_operation'])
_MUTATEOPERATION.fields_by_name['campaign_shared_set_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['conversion_action_operation'])
_MUTATEOPERATION.fields_by_name['conversion_action_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['customer_extension_setting_operation'])
_MUTATEOPERATION.fields_by_name['customer_extension_setting_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['customer_feed_operation'])
_MUTATEOPERATION.fields_by_name['customer_feed_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['customer_label_operation'])
_MUTATEOPERATION.fields_by_name['customer_label_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['customer_negative_criterion_operation'])
_MUTATEOPERATION.fields_by_name['customer_negative_criterion_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['customer_operation'])
_MUTATEOPERATION.fields_by_name['customer_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['extension_feed_item_operation'])
_MUTATEOPERATION.fields_by_name['extension_feed_item_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['feed_item_operation'])
_MUTATEOPERATION.fields_by_name['feed_item_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['feed_item_target_operation'])
_MUTATEOPERATION.fields_by_name['feed_item_target_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['feed_mapping_operation'])
_MUTATEOPERATION.fields_by_name['feed_mapping_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['feed_operation'])
_MUTATEOPERATION.fields_by_name['feed_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['label_operation'])
_MUTATEOPERATION.fields_by_name['label_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['media_file_operation'])
_MUTATEOPERATION.fields_by_name['media_file_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['remarketing_action_operation'])
_MUTATEOPERATION.fields_by_name['remarketing_action_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['shared_criterion_operation'])
_MUTATEOPERATION.fields_by_name['shared_criterion_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['shared_set_operation'])
_MUTATEOPERATION.fields_by_name['shared_set_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATION.oneofs_by_name['operation'].fields.append(
  _MUTATEOPERATION.fields_by_name['user_list_operation'])
_MUTATEOPERATION.fields_by_name['user_list_operation'].containing_oneof = _MUTATEOPERATION.oneofs_by_name['operation']
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_ad_label_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2._MUTATEADGROUPADLABELRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_ad_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2._MUTATEADGROUPADRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_bid_modifier_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__bid__modifier__service__pb2._MUTATEADGROUPBIDMODIFIERRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_criterion_label_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__criterion__label__service__pb2._MUTATEADGROUPCRITERIONLABELRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_criterion_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__criterion__service__pb2._MUTATEADGROUPCRITERIONRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_extension_setting_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2._MUTATEADGROUPEXTENSIONSETTINGRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_feed_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__feed__service__pb2._MUTATEADGROUPFEEDRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_label_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__label__service__pb2._MUTATEADGROUPLABELRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2._MUTATEADGROUPRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_parameter_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__parameter__service__pb2._MUTATEADPARAMETERRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['asset_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_asset__service__pb2._MUTATEASSETRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['bidding_strategy_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_bidding__strategy__service__pb2._MUTATEBIDDINGSTRATEGYRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_bid_modifier_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__bid__modifier__service__pb2._MUTATECAMPAIGNBIDMODIFIERRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_budget_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__budget__service__pb2._MUTATECAMPAIGNBUDGETRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_criterion_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__criterion__service__pb2._MUTATECAMPAIGNCRITERIONRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_draft_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2._MUTATECAMPAIGNDRAFTRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_experiment_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2._MUTATECAMPAIGNEXPERIMENTRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_extension_setting_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__extension__setting__service__pb2._MUTATECAMPAIGNEXTENSIONSETTINGRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_feed_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2._MUTATECAMPAIGNFEEDRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_label_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__label__service__pb2._MUTATECAMPAIGNLABELRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__service__pb2._MUTATECAMPAIGNRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_shared_set_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2._MUTATECAMPAIGNSHAREDSETRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['conversion_action_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__action__service__pb2._MUTATECONVERSIONACTIONRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_extension_setting_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__extension__setting__service__pb2._MUTATECUSTOMEREXTENSIONSETTINGRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_feed_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__feed__service__pb2._MUTATECUSTOMERFEEDRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_label_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__label__service__pb2._MUTATECUSTOMERLABELRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_negative_criterion_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__negative__criterion__service__pb2._MUTATECUSTOMERNEGATIVECRITERIARESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_customer__service__pb2._MUTATECUSTOMERRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['extension_feed_item_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_extension__feed__item__service__pb2._MUTATEEXTENSIONFEEDITEMRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['feed_item_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2._MUTATEFEEDITEMRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['feed_item_target_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2._MUTATEFEEDITEMTARGETRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['feed_mapping_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__mapping__service__pb2._MUTATEFEEDMAPPINGRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['feed_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__service__pb2._MUTATEFEEDRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['label_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_label__service__pb2._MUTATELABELRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['media_file_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_media__file__service__pb2._MUTATEMEDIAFILERESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['remarketing_action_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2._MUTATEREMARKETINGACTIONRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['shared_criterion_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_shared__criterion__service__pb2._MUTATESHAREDCRITERIONRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['shared_set_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_shared__set__service__pb2._MUTATESHAREDSETRESULT
_MUTATEOPERATIONRESPONSE.fields_by_name['user_list_result'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2._MUTATEUSERLISTRESULT
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_ad_label_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_ad_label_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_ad_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_ad_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_bid_modifier_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_bid_modifier_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_criterion_label_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_criterion_label_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_criterion_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_criterion_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_extension_setting_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_extension_setting_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_feed_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_feed_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_label_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_label_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_group_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['ad_parameter_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['ad_parameter_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['asset_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['asset_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['bidding_strategy_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['bidding_strategy_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_bid_modifier_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_bid_modifier_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_budget_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_budget_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_criterion_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_criterion_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_draft_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_draft_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_experiment_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_experiment_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_extension_setting_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_extension_setting_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_feed_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_feed_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_label_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_label_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['campaign_shared_set_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['campaign_shared_set_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['conversion_action_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['conversion_action_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['customer_extension_setting_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_extension_setting_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['customer_feed_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_feed_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['customer_label_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_label_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['customer_negative_criterion_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_negative_criterion_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['customer_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['customer_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['extension_feed_item_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['extension_feed_item_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['feed_item_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['feed_item_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['feed_item_target_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['feed_item_target_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['feed_mapping_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['feed_mapping_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['feed_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['feed_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['label_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['label_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['media_file_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['media_file_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['remarketing_action_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['remarketing_action_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['shared_criterion_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['shared_criterion_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['shared_set_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['shared_set_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
_MUTATEOPERATIONRESPONSE.oneofs_by_name['response'].fields.append(
  _MUTATEOPERATIONRESPONSE.fields_by_name['user_list_result'])
_MUTATEOPERATIONRESPONSE.fields_by_name['user_list_result'].containing_oneof = _MUTATEOPERATIONRESPONSE.oneofs_by_name['response']
DESCRIPTOR.message_types_by_name['SearchGoogleAdsRequest'] = _SEARCHGOOGLEADSREQUEST
DESCRIPTOR.message_types_by_name['SearchGoogleAdsResponse'] = _SEARCHGOOGLEADSRESPONSE
DESCRIPTOR.message_types_by_name['GoogleAdsRow'] = _GOOGLEADSROW
DESCRIPTOR.message_types_by_name['MutateGoogleAdsRequest'] = _MUTATEGOOGLEADSREQUEST
DESCRIPTOR.message_types_by_name['MutateGoogleAdsResponse'] = _MUTATEGOOGLEADSRESPONSE
DESCRIPTOR.message_types_by_name['MutateOperation'] = _MUTATEOPERATION
DESCRIPTOR.message_types_by_name['MutateOperationResponse'] = _MUTATEOPERATIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchGoogleAdsRequest = _reflection.GeneratedProtocolMessageType('SearchGoogleAdsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHGOOGLEADSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.google_ads_service_pb2'
  ,
  __doc__ = """Request message for
  [GoogleAdsService.Search][google.ads.googleads.v2.services.GoogleAdsService.Search].
  
  
  Attributes:
      customer_id:
          The ID of the customer being queried.
      query:
          The query string.
      page_token:
          Token of the page to retrieve. If not specified, the first
          page of results will be returned. Use the value obtained from
          ``next_page_token`` in the previous response in order to
          request the next page of results.
      page_size:
          Number of elements to retrieve in a single page. When too
          large a page is requested, the server may decide to further
          limit the number of returned resources.
      validate_only:
          If true, the request is validated but not executed.
      return_summary_row:
          If true, summary row will be included in the response.
          Otherwise(false or not specified) summary row will not be
          returned.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.SearchGoogleAdsRequest)
  ))
_sym_db.RegisterMessage(SearchGoogleAdsRequest)

SearchGoogleAdsResponse = _reflection.GeneratedProtocolMessageType('SearchGoogleAdsResponse', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHGOOGLEADSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.google_ads_service_pb2'
  ,
  __doc__ = """Response message for
  [GoogleAdsService.Search][google.ads.googleads.v2.services.GoogleAdsService.Search].
  
  
  Attributes:
      results:
          The list of rows that matched the query.
      next_page_token:
          Pagination token used to retrieve the next page of results.
          Pass the content of this string as the ``page_token``
          attribute of the next request. ``next_page_token`` is not
          returned for the last page.
      total_results_count:
          Total number of results that match the query ignoring the
          LIMIT clause.
      field_mask:
          FieldMask that represents what fields were requested by the
          user.
      summary_row:
          Summary row that contains summary of metrics in results.
          Summary of metrics means aggregation of metrics across all
          results, here aggregation could be sum, average, rate, etc.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.SearchGoogleAdsResponse)
  ))
_sym_db.RegisterMessage(SearchGoogleAdsResponse)

GoogleAdsRow = _reflection.GeneratedProtocolMessageType('GoogleAdsRow', (_message.Message,), dict(
  DESCRIPTOR = _GOOGLEADSROW,
  __module__ = 'google.ads.googleads_v2.proto.services.google_ads_service_pb2'
  ,
  __doc__ = """A returned row from the query.
  
  
  Attributes:
      account_budget:
          The account budget in the query.
      account_budget_proposal:
          The account budget proposal referenced in the query.
      ad_group:
          The ad group referenced in the query.
      ad_group_ad:
          The ad referenced in the query.
      ad_group_ad_asset_view:
          The ad group ad asset view in the query.
      ad_group_ad_label:
          The ad group ad label referenced in the query.
      ad_group_audience_view:
          The ad group audience view referenced in the query.
      ad_group_bid_modifier:
          The bid modifier referenced in the query.
      ad_group_criterion:
          The criterion referenced in the query.
      ad_group_criterion_label:
          The ad group criterion label referenced in the query.
      ad_group_criterion_simulation:
          The ad group criterion simulation referenced in the query.
      ad_group_extension_setting:
          The ad group extension setting referenced in the query.
      ad_group_feed:
          The ad group feed referenced in the query.
      ad_group_label:
          The ad group label referenced in the query.
      ad_group_simulation:
          The ad group simulation referenced in the query.
      ad_parameter:
          The ad parameter referenced in the query.
      age_range_view:
          The age range view referenced in the query.
      ad_schedule_view:
          The ad schedule view referenced in the query.
      domain_category:
          The domain category referenced in the query.
      asset:
          The asset referenced in the query.
      bidding_strategy:
          The bidding strategy referenced in the query.
      billing_setup:
          The billing setup referenced in the query.
      campaign_budget:
          The campaign budget referenced in the query.
      campaign:
          The campaign referenced in the query.
      campaign_audience_view:
          The campaign audience view referenced in the query.
      campaign_bid_modifier:
          The campaign bid modifier referenced in the query.
      campaign_criterion:
          The campaign criterion referenced in the query.
      campaign_criterion_simulation:
          The campaign criterion simulation referenced in the query.
      campaign_draft:
          The campaign draft referenced in the query.
      campaign_experiment:
          The campaign experiment referenced in the query.
      campaign_extension_setting:
          The campaign extension setting referenced in the query.
      campaign_feed:
          The campaign feed referenced in the query.
      campaign_label:
          The campaign label referenced in the query.
      campaign_shared_set:
          Campaign Shared Set referenced in AWQL query.
      carrier_constant:
          The carrier constant referenced in the query.
      change_status:
          The ChangeStatus referenced in the query.
      conversion_action:
          The conversion action referenced in the query.
      click_view:
          The ClickView referenced in the query.
      custom_interest:
          The CustomInterest referenced in the query.
      customer:
          The customer referenced in the query.
      customer_manager_link:
          The CustomerManagerLink referenced in the query.
      customer_client_link:
          The CustomerClientLink referenced in the query.
      customer_client:
          The CustomerClient referenced in the query.
      customer_extension_setting:
          The customer extension setting referenced in the query.
      customer_feed:
          The customer feed referenced in the query.
      customer_label:
          The customer label referenced in the query.
      customer_negative_criterion:
          The customer negative criterion referenced in the query.
      detail_placement_view:
          The detail placement view referenced in the query.
      display_keyword_view:
          The display keyword view referenced in the query.
      distance_view:
          The distance view referenced in the query.
      dynamic_search_ads_search_term_view:
          The dynamic search ads search term view referenced in the
          query.
      expanded_landing_page_view:
          The expanded landing page view referenced in the query.
      extension_feed_item:
          The extension feed item referenced in the query.
      feed:
          The feed referenced in the query.
      feed_item:
          The feed item referenced in the query.
      feed_item_target:
          The feed item target referenced in the query.
      feed_mapping:
          The feed mapping referenced in the query.
      feed_placeholder_view:
          The feed placeholder view referenced in the query.
      gender_view:
          The gender view referenced in the query.
      geo_target_constant:
          The geo target constant referenced in the query.
      geographic_view:
          The geographic view referenced in the query.
      group_placement_view:
          The group placement view referenced in the query.
      hotel_group_view:
          The hotel group view referenced in the query.
      hotel_performance_view:
          The hotel performance view referenced in the query.
      keyword_view:
          The keyword view referenced in the query.
      keyword_plan:
          The keyword plan referenced in the query.
      keyword_plan_campaign:
          The keyword plan campaign referenced in the query.
      keyword_plan_negative_keyword:
          The keyword plan negative keyword referenced in the query.
      keyword_plan_ad_group:
          The keyword plan ad group referenced in the query.
      keyword_plan_keyword:
          The keyword plan keyword referenced in the query.
      label:
          The label referenced in the query.
      landing_page_view:
          The landing page view referenced in the query.
      language_constant:
          The language constant referenced in the query.
      location_view:
          The location view referenced in the query.
      managed_placement_view:
          The managed placement view referenced in the query.
      media_file:
          The media file referenced in the query.
      mobile_app_category_constant:
          The mobile app category constant referenced in the query.
      mobile_device_constant:
          The mobile device constant referenced in the query.
      mutate_job:
          The mutate job referenced in the query.
      operating_system_version_constant:
          The operating system version constant referenced in the query.
      paid_organic_search_term_view:
          The paid organic search term view referenced in the query.
      parental_status_view:
          The parental status view referenced in the query.
      product_bidding_category_constant:
          The Product Bidding Category referenced in the query.
      product_group_view:
          The product group view referenced in the query.
      recommendation:
          The recommendation referenced in the query.
      search_term_view:
          The search term view referenced in the query.
      shared_criterion:
          The shared set referenced in the query.
      shared_set:
          The shared set referenced in the query.
      shopping_performance_view:
          The shopping performance view referenced in the query.
      topic_view:
          The topic view referenced in the query.
      user_interest:
          The user interest referenced in the query.
      user_list:
          The user list referenced in the query.
      user_location_view:
          The user location view referenced in the query.
      remarketing_action:
          The remarketing action referenced in the query.
      topic_constant:
          The topic constant referenced in the query.
      video:
          The video referenced in the query.
      metrics:
          The metrics.
      segments:
          The segments.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GoogleAdsRow)
  ))
_sym_db.RegisterMessage(GoogleAdsRow)

MutateGoogleAdsRequest = _reflection.GeneratedProtocolMessageType('MutateGoogleAdsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEGOOGLEADSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.google_ads_service_pb2'
  ,
  __doc__ = """Request message for
  [GoogleAdsService.Mutate][google.ads.googleads.v2.services.GoogleAdsService.Mutate].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose resources are being modified.
      mutate_operations:
          The list of operations to perform on individual resources.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateGoogleAdsRequest)
  ))
_sym_db.RegisterMessage(MutateGoogleAdsRequest)

MutateGoogleAdsResponse = _reflection.GeneratedProtocolMessageType('MutateGoogleAdsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEGOOGLEADSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.google_ads_service_pb2'
  ,
  __doc__ = """Response message for
  [GoogleAdsService.Mutate][google.ads.googleads.v2.services.GoogleAdsService.Mutate].
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g., auth errors), we return an RPC
          level error.
      mutate_operation_responses:
          All responses for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateGoogleAdsResponse)
  ))
_sym_db.RegisterMessage(MutateGoogleAdsResponse)

MutateOperation = _reflection.GeneratedProtocolMessageType('MutateOperation', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.google_ads_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a resource.
  
  
  Attributes:
      operation:
          The mutate operation.
      ad_group_ad_label_operation:
          An ad group ad label mutate operation.
      ad_group_ad_operation:
          An ad group ad mutate operation.
      ad_group_bid_modifier_operation:
          An ad group bid modifier mutate operation.
      ad_group_criterion_label_operation:
          An ad group criterion label mutate operation.
      ad_group_criterion_operation:
          An ad group criterion mutate operation.
      ad_group_extension_setting_operation:
          An ad group extension setting mutate operation.
      ad_group_feed_operation:
          An ad group feed mutate operation.
      ad_group_label_operation:
          An ad group label mutate operation.
      ad_group_operation:
          An ad group mutate operation.
      ad_parameter_operation:
          An ad parameter mutate operation.
      asset_operation:
          An asset mutate operation.
      bidding_strategy_operation:
          A bidding strategy mutate operation.
      campaign_bid_modifier_operation:
          A campaign bid modifier mutate operation.
      campaign_budget_operation:
          A campaign budget mutate operation.
      campaign_criterion_operation:
          A campaign criterion mutate operation.
      campaign_draft_operation:
          A campaign draft mutate operation.
      campaign_experiment_operation:
          A campaign experiment mutate operation.
      campaign_extension_setting_operation:
          A campaign extension setting mutate operation.
      campaign_feed_operation:
          A campaign feed mutate operation.
      campaign_label_operation:
          A campaign label mutate operation.
      campaign_operation:
          A campaign mutate operation.
      campaign_shared_set_operation:
          A campaign shared set mutate operation.
      conversion_action_operation:
          A conversion action mutate operation.
      customer_extension_setting_operation:
          A customer extension setting mutate operation.
      customer_feed_operation:
          A customer feed mutate operation.
      customer_label_operation:
          A customer label mutate operation.
      customer_negative_criterion_operation:
          A customer negative criterion mutate operation.
      customer_operation:
          A customer mutate operation.
      extension_feed_item_operation:
          An extension feed item mutate operation.
      feed_item_operation:
          A feed item mutate operation.
      feed_item_target_operation:
          A feed item target mutate operation.
      feed_mapping_operation:
          A feed mapping mutate operation.
      feed_operation:
          A feed mutate operation.
      label_operation:
          A label mutate operation.
      media_file_operation:
          A media file mutate operation.
      remarketing_action_operation:
          A remarketing action mutate operation.
      shared_criterion_operation:
          A shared criterion mutate operation.
      shared_set_operation:
          A shared set mutate operation.
      user_list_operation:
          A user list mutate operation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateOperation)
  ))
_sym_db.RegisterMessage(MutateOperation)

MutateOperationResponse = _reflection.GeneratedProtocolMessageType('MutateOperationResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEOPERATIONRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.google_ads_service_pb2'
  ,
  __doc__ = """Response message for the resource mutate.
  
  
  Attributes:
      response:
          The mutate response.
      ad_group_ad_label_result:
          The result for the ad group ad label mutate.
      ad_group_ad_result:
          The result for the ad group ad mutate.
      ad_group_bid_modifier_result:
          The result for the ad group bid modifier mutate.
      ad_group_criterion_label_result:
          The result for the ad group criterion label mutate.
      ad_group_criterion_result:
          The result for the ad group criterion mutate.
      ad_group_extension_setting_result:
          The result for the ad group extension setting mutate.
      ad_group_feed_result:
          The result for the ad group feed mutate.
      ad_group_label_result:
          The result for the ad group label mutate.
      ad_group_result:
          The result for the ad group mutate.
      ad_parameter_result:
          The result for the ad parameter mutate.
      asset_result:
          The result for the asset mutate.
      bidding_strategy_result:
          The result for the bidding strategy mutate.
      campaign_bid_modifier_result:
          The result for the campaign bid modifier mutate.
      campaign_budget_result:
          The result for the campaign budget mutate.
      campaign_criterion_result:
          The result for the campaign criterion mutate.
      campaign_draft_result:
          The result for the campaign draft mutate.
      campaign_experiment_result:
          The result for the campaign experiment mutate.
      campaign_extension_setting_result:
          The result for the campaign extension setting mutate.
      campaign_feed_result:
          The result for the campaign feed mutate.
      campaign_label_result:
          The result for the campaign label mutate.
      campaign_result:
          The result for the campaign mutate.
      campaign_shared_set_result:
          The result for the campaign shared set mutate.
      conversion_action_result:
          The result for the conversion action mutate.
      customer_extension_setting_result:
          The result for the customer extension setting mutate.
      customer_feed_result:
          The result for the customer feed mutate.
      customer_label_result:
          The result for the customer label mutate.
      customer_negative_criterion_result:
          The result for the customer negative criterion mutate.
      customer_result:
          The result for the customer mutate.
      extension_feed_item_result:
          The result for the extension feed item mutate.
      feed_item_result:
          The result for the feed item mutate.
      feed_item_target_result:
          The result for the feed item target mutate.
      feed_mapping_result:
          The result for the feed mapping mutate.
      feed_result:
          The result for the feed mutate.
      label_result:
          The result for the label mutate.
      media_file_result:
          The result for the media file mutate.
      remarketing_action_result:
          The result for the remarketing action mutate.
      shared_criterion_result:
          The result for the shared criterion mutate.
      shared_set_result:
          The result for the shared set mutate.
      user_list_result:
          The result for the user list mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateOperationResponse)
  ))
_sym_db.RegisterMessage(MutateOperationResponse)


DESCRIPTOR._options = None

_GOOGLEADSSERVICE = _descriptor.ServiceDescriptor(
  name='GoogleAdsService',
  full_name='google.ads.googleads.v2.services.GoogleAdsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=25442,
  serialized_end=25863,
  methods=[
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='google.ads.googleads.v2.services.GoogleAdsService.Search',
    index=0,
    containing_service=None,
    input_type=_SEARCHGOOGLEADSREQUEST,
    output_type=_SEARCHGOOGLEADSRESPONSE,
    serialized_options=_b('\202\323\344\223\0023\"./v2/customers/{customer_id=*}/googleAds:search:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='Mutate',
    full_name='google.ads.googleads.v2.services.GoogleAdsService.Mutate',
    index=1,
    containing_service=None,
    input_type=_MUTATEGOOGLEADSREQUEST,
    output_type=_MUTATEGOOGLEADSRESPONSE,
    serialized_options=_b('\202\323\344\223\0023\"./v2/customers/{customer_id=*}/googleAds:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_GOOGLEADSSERVICE)

DESCRIPTOR.services_by_name['GoogleAdsService'] = _GOOGLEADSSERVICE

# @@protoc_insertion_point(module_scope)
